/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <stdbool.h>
/************ Begin %include sections from the grammar ************************/
#line 55 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"

#include "sqlInt.h"
#include "box/fk_constraint.h"

/*
** Disable all error recovery processing in the parser push-down
** automaton.
*/
#define YYNOERRORRECOVERY 1

/*
** Make yytestcase() the same as testcase()
*/
#define yytestcase(X) testcase(X)

/*
** Indicate that sqlParserFree() will never be called with a null
** pointer.
*/
#define YYPARSEFREENEVERNULL 1

/*
** Alternative datatype for the argument to the malloc() routine passed
** into sqlParserAlloc().  The default is size_t.
*/
#define YYMALLOCARGTYPE  u64

/*
 * Stop the parser if an error occurs. This macro adds an
 * additional check that allows the parser to be stopped if any
 * error was noticed.
 */
#define PARSER_ERROR_CHECK && ! pParse->is_aborted

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** Disable lookaside memory allocation for objects that might be
** shared across database connections.
*/
static void disableLookaside(Parse *pParse){
  pParse->disableLookaside++;
  pParse->db->lookaside.bDisable++;
}

#line 440 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"

  /**
   * For a compound SELECT statement, make sure
   * p->pPrior->pNext==p for all elements in the list. And make
   * sure list length does not exceed SQL_LIMIT_COMPOUND_SELECT.
   */
  static void parserDoubleLinkSelect(Parse *pParse, Select *p){
    if( p->pPrior ){
      Select *pNext = 0, *pLoop;
      int mxSelect, cnt = 0;
      for(pLoop=p; pLoop; pNext=pLoop, pLoop=pLoop->pPrior, cnt++){
        pLoop->pNext = pNext;
        pLoop->selFlags |= SF_Compound;
      }
      if( (p->selFlags & SF_MultiValue)==0 && 
        (mxSelect = pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT])>0 &&
        cnt>mxSelect
      ){
         diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of UNION or "\
                  "EXCEPT or INTERSECT operations", cnt,
                  pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT]);
         pParse->is_aborted = true;
      }
    }
  }
#line 890 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"

  /* This is a utility routine used to set the ExprSpan.zStart and
  ** ExprSpan.zEnd values of pOut so that the span covers the complete
  ** range of text beginning with pStart and going to the end of pEnd.
  */
  static void spanSet(ExprSpan *pOut, Token *pStart, Token *pEnd){
    pOut->zStart = pStart->z;
    pOut->zEnd = &pEnd->z[pEnd->n];
  }

  /* Construct a new Expr object from a single identifier.  Use the
  ** new Expr to populate pOut.  Set the span of pOut to be the identifier
  ** that created the expression.
  */
  static void spanExpr(ExprSpan *pOut, Parse *pParse, int op, Token t){
    struct Expr *p = NULL;
    int name_sz = t.n + 1;
    p = sqlDbMallocRawNN(pParse->db, sizeof(Expr) + name_sz);
    if( p ){
      memset(p, 0, sizeof(Expr));
      switch (op) {
      case TK_STRING:
        p->type = FIELD_TYPE_STRING;
        break;
      case TK_BLOB:
        p->type = FIELD_TYPE_VARBINARY;
        break;
      case TK_INTEGER:
        p->type = FIELD_TYPE_INTEGER;
        break;
      case TK_FLOAT:
        p->type = FIELD_TYPE_NUMBER;
        break;
      case TK_TRUE:
      case TK_FALSE:
      case TK_UNKNOWN:
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      case TK_VARIABLE:
        /*
         * For variables we set BOOLEAN type since
         * unassigned bindings will be replaced
         * with NULL automatically, i.e. without
         * explicit call of sql_bind_*().
         */
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      default:
        p->type = FIELD_TYPE_SCALAR;
        break;
      }
      p->op = (u8)op;
      p->flags = EP_Leaf;
      p->iAgg = -1;
      p->u.zToken = (char*)&p[1];
      if (op != TK_VARIABLE) {
        int rc = sql_normalize_name(p->u.zToken, name_sz, t.z, t.n);
        if (rc > name_sz) {
          name_sz = rc;
          p = sqlDbReallocOrFree(pParse->db, p, sizeof(*p) + name_sz);
          if (p == NULL)
            goto tarantool_error;
          p->u.zToken = (char *) &p[1];
          if (sql_normalize_name(p->u.zToken, name_sz, t.z, t.n) > name_sz)
              unreachable();
        }
      } else {
        memcpy(p->u.zToken, t.z, t.n);
        p->u.zToken[t.n] = 0;
      }
#if SQL_MAX_EXPR_DEPTH>0
      p->nHeight = 1;
#endif  
    }
    pOut->pExpr = p;
    pOut->zStart = t.z;
    pOut->zEnd = &t.z[t.n];
    return;
tarantool_error:
    sqlDbFree(pParse->db, p);
    pParse->is_aborted = true;
  }
#line 1147 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"

  /* This routine constructs a binary expression node out of two ExprSpan
  ** objects and uses the result to populate a new ExprSpan object.
  */
  static void spanBinaryExpr(
    Parse *pParse,      /* The parsing context.  Errors accumulate here */
    int op,             /* The binary operation */
    ExprSpan *pLeft,    /* The left operand, and output */
    ExprSpan *pRight    /* The right operand */
  ){
    pLeft->pExpr = sqlPExpr(pParse, op, pLeft->pExpr, pRight->pExpr);
    pLeft->zEnd = pRight->zEnd;
  }

  /* If doNot is true, then add a TK_NOT Expr-node wrapper around the
  ** outside of *ppExpr.
  */
  static void exprNot(Parse *pParse, int doNot, ExprSpan *pSpan){
    if( doNot ){
      pSpan->pExpr = sqlPExpr(pParse, TK_NOT, pSpan->pExpr, 0);
    }
  }
#line 1221 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"

  /* Construct an expression node for a unary postfix operator
  */
  static void spanUnaryPostfix(
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand, and output */
    Token *pPostOp         /* The operand token for setting the span */
  ){
    pOperand->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOperand->zEnd = &pPostOp->z[pPostOp->n];
  }                           
#line 1242 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"

  /* Construct an expression node for a unary prefix operator
  */
  static void spanUnaryPrefix(
    ExprSpan *pOut,        /* Write the new expression node here */
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand */
    Token *pPreOp         /* The operand token for setting the span */
  ){
    pOut->zStart = pPreOp->z;
    pOut->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOut->zEnd = pOperand->zEnd;
  }
#line 1444 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"

  /* Add a single new term to an ExprList that is used to store a
  ** list of identifiers.  Report an error if the ID list contains
  ** a COLLATE clause or an ASC or DESC keyword, except ignore the
  ** error while parsing a legacy schema.
  */
  static ExprList *parserAddExprIdListTerm(
    Parse *pParse,
    ExprList *pPrior,
    Token *pIdToken
  ){
    ExprList *p = sql_expr_list_append(pParse->db, pPrior, NULL);
    sqlExprListSetName(pParse, p, pIdToken, 1);
    return p;
  }
#line 1677 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"

  struct alter_args {
    struct SrcList *table_name;
    /** Name of constraint OR new name of table in case of RENAME. */
    struct Token name;
  };
#line 276 "parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next sections is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    sqlParserTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is sqlParserTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 257
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 70
#define sqlParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlParserTOKENTYPE yy0;
  Expr* yy2;
  SrcList* yy3;
  With* yy4;
  struct LimitVal yy20;
  Select* yy43;
  struct Expr * yy87;
  struct SrcList * yy120;
  ExprSpan yy150;
  struct Token yy167;
  struct ExprList * yy215;
  IdList* yy272;
  struct TrigEvent yy338;
  TriggerStep* yy347;
  int yy348;
  ExprList* yy402;
  struct alter_args yy426;
  enum trim_side_mask yy429;
  struct type_def yy434;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlParserARG_SDECL Parse *pParse;
#define sqlParserARG_PDECL ,Parse *pParse
#define sqlParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlParserARG_STORE yypParser->pParse = pParse
#define YYFALLBACK 1
#define YYNSTATE             424
#define YYNRULE              312
#define YY_MAX_SHIFT         423
#define YY_MIN_SHIFTREDUCE   640
#define YY_MAX_SHIFTREDUCE   951
#define YY_MIN_REDUCE        952
#define YY_MAX_REDUCE        1263
#define YY_ERROR_ACTION      1264
#define YY_ACCEPT_ACTION     1265
#define YY_NO_ACTION         1266
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (1530)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    61,   62,  280,  302,  815,  815,  825,  828,   59,   59,
 /*    10 */    60,   60,   60,   60,  295,   58,   58,   58,   58,   57,
 /*    20 */    57,   56,   56,   56,   55,  303,  303,   61,   62,  280,
 /*    30 */   302,  815,  815,  825,  828,   59,   59,   60,   60,   60,
 /*    40 */    60,  933,   58,   58,   58,   58,   57,   57,   56,   56,
 /*    50 */    56,   55,  303,   62,  280,  302,  815,  815,  825,  828,
 /*    60 */    59,   59,   60,   60,   60,   60,  933,   58,   58,   58,
 /*    70 */    58,   57,   57,   56,   56,   56,   55,  303,   57,   57,
 /*    80 */    56,   56,   56,   55,  303,  422,  422,  211,  351,  272,
 /*    90 */   778,  124,  348,   61,   62,  280,  302,  815,  815,  825,
 /*   100 */   828,   59,   59,   60,   60,   60,   60,   48,   58,   58,
 /*   110 */    58,   58,   57,   57,   56,   56,   56,   55,  303,  641,
 /*   120 */   307,  774,  217,  709,   45,   46,   70,  656,  656,  751,
 /*   130 */   752,   47,   25,   38,  120,  771,  237,  337,  112,  305,
 /*   140 */   305,  275,  409,    4,  127,  278,  304,  304,  851,  722,
 /*   150 */   331,  305,   63,  219,   58,   58,   58,   58,   57,   57,
 /*   160 */    56,   56,   56,   55,  303,  398,   54,   52,  181,  145,
 /*   170 */   238,  785,  656,  656,  780,  283,  284,  164,   54,   52,
 /*   180 */   181,   60,   60,   60,   60,   53,   58,   58,   58,   58,
 /*   190 */    57,   57,   56,   56,   56,   55,  303,  127,   60,   60,
 /*   200 */    60,   60,  782,   58,   58,   58,   58,   57,   57,   56,
 /*   210 */    56,   56,   55,  303,   55,  303,  784,  784,  786,  787,
 /*   220 */   788,  789,  790,  417,  413,  800,  801,  802,  937,   19,
 /*   230 */    61,   62,  280,  302,  815,  815,  825,  828,   59,   59,
 /*   240 */    60,   60,   60,   60,  659,   58,   58,   58,   58,   57,
 /*   250 */    57,   56,   56,   56,   55,  303,  903,  904,  905,  906,
 /*   260 */   907,  908,  266,  911,  912,  912,  913,  218,  374,  892,
 /*   270 */    56,   56,   56,   55,  303,   61,   62,  280,  302,  815,
 /*   280 */   815,  825,  828,   59,   59,   60,   60,   60,   60,   67,
 /*   290 */    58,   58,   58,   58,   57,   57,   56,   56,   56,   55,
 /*   300 */   303,  785,  120,  231,  780,  177,  736,  882,  920,  276,
 /*   310 */   112, 1210, 1210,  278,  667,  701,  701,  320,   66,  920,
 /*   320 */    61,   62,  280,  302,  815,  815,  825,  828,   59,   59,
 /*   330 */    60,   60,   60,   60,  338,   58,   58,   58,   58,   57,
 /*   340 */    57,   56,   56,   56,   55,  303,  784,  784,  786,  787,
 /*   350 */   788,  789,   71,  699,  699,  230,  127,  336,  655,  660,
 /*   360 */   854,  309,  416,  170,  736,   61,   62,  280,  302,  815,
 /*   370 */   815,  825,  828,   59,   59,   60,   60,   60,   60,  419,
 /*   380 */    58,   58,   58,   58,   57,   57,   56,   56,   56,   55,
 /*   390 */   303,   81,   81,  322,  321,  322,  750,  229,  924,  279,
 /*   400 */   228,  680,  681,  682,  806,  924, 1265,  423,    2,  669,
 /*   410 */    61,   62,  280,  302,  815,  815,  825,  828,   59,   59,
 /*   420 */    60,   60,   60,   60,  678,   58,   58,   58,   58,   57,
 /*   430 */    57,   56,   56,   56,   55,  303,  854,  856,  854,  362,
 /*   440 */   359,  366,  655,  412,   49,   18,  416,  411,  662,  779,
 /*   450 */    54,   52,  181,  358,  661,   61,   62,  280,  302,  815,
 /*   460 */   815,  825,  828,   59,   59,   60,   60,   60,   60,  679,
 /*   470 */    58,   58,   58,   58,   57,   57,   56,   56,   56,   55,
 /*   480 */   303,   61,   62,  280,  302,  815,  815,  825,  828,   59,
 /*   490 */    59,   60,   60,   60,   60,  729,   58,   58,   58,   58,
 /*   500 */    57,   57,   56,   56,   56,   55,  303,   61,   62,  280,
 /*   510 */   302,  815,  815,  825,  828,   59,   59,   60,   60,   60,
 /*   520 */    60,  264,   58,   58,   58,   58,   57,   57,   56,   56,
 /*   530 */    56,   55,  303,   61,   62,  280,  302,  815,  815,  825,
 /*   540 */   828,   59,   59,   60,   60,   60,   60,   48,   58,   58,
 /*   550 */    58,   58,   57,   57,   56,   56,   56,   55,  303,  774,
 /*   560 */   934,  934,  332,  868,   45,   46,  128,  749,  247,  246,
 /*   570 */   891,   47,  298,  384,  226,  327,  419,  891,  286,  285,
 /*   580 */   419,   40,  409,    4, 1152,  378,  304,  304,   23,   23,
 /*   590 */   218,  374,   98,   98,  340,  294,  868,   22,   22,  851,
 /*   600 */   656,  656,  282,  796,  169,  398,  355,   43,  238, 1234,
 /*   610 */  1234,  785,  407,  340,  780,  390,  935,  738,  112,  419,
 /*   620 */   121,   54,   52,  181,  851,  940,  292,  946,  696,  393,
 /*   630 */   391,   23,   23,  686,  944,  696,  945,  219,  161,  253,
 /*   640 */   880,  364,  782,  112,  411,  291,  687,  148,  411,  247,
 /*   650 */   246,  301,  245,  411,  885,  190,  784,  784,  786,  787,
 /*   660 */   788,  789,  790,  417,  413,  296,  719,  886,  937,   19,
 /*   670 */   947,  718,  942,  941,  196,  947,  146,  887,  702,  656,
 /*   680 */   656,  668,  127,  247,  246,  703,  245,  411,   61,   62,
 /*   690 */   280,  302,  815,  815,  825,  828,   59,   59,   60,   60,
 /*   700 */    60,   60,  210,   58,   58,   58,   58,   57,   57,   56,
 /*   710 */    56,   56,   55,  303,   61,   51,  280,  302,  815,  815,
 /*   720 */   825,  828,   59,   59,   60,   60,   60,   60,   48,   58,
 /*   730 */    58,   58,   58,   57,   57,   56,   56,   56,   55,  303,
 /*   740 */   656,  656,  298,  182,  182,   45,   46,  862,    6,  419,
 /*   750 */   778,  933,   47,  369,  882,  377,  774,  112,  182,  182,
 /*   760 */   264,   78,   78,  409,    4,  294,  324,  304,  304,  325,
 /*   770 */   377,  237,  337,  865,  711,  864,  933,  163,  162, 1233,
 /*   780 */  1233,  338,  335,  330,  371,  377,  398,  112,  419,  308,
 /*   790 */   894,  310,  785,  172,   48,  780,   65,  211,  372,  724,
 /*   800 */    23,   23,  735,  313,  347,  238,  396,  219,  161,  253,
 /*   810 */   288,   45,   46,  723,  293,  656,  656,  411,   47,  656,
 /*   820 */   656,  719,  245,  782,  785,  736,  718,  780,  379,  409,
 /*   830 */     4,  112,  127,  304,  304,  127,  317,  784,  784,  786,
 /*   840 */   787,  788,  789,  790,  417,  413,  167,  179,  342,  937,
 /*   850 */    19,  403,  398,  778,  419,   44,  411,   42,  785,  778,
 /*   860 */    48,  780,  783,  127,  934,  934,   23,   23,  735,  784,
 /*   870 */   784,  786,  787,  788,  789,  419,  932,   45,   46,  419,
 /*   880 */   205,  419,  170,  736,   47,  419,  174,   23,   23,  782,
 /*   890 */   255,   98,   98,   98,   98,  409,    4,   98,   98,  304,
 /*   900 */   304,  387,  763,  784,  784,  786,  787,  788,  789,  790,
 /*   910 */   417,  413,  151,  289,  735,  937,   19,  735,  398,  290,
 /*   920 */   935,  737,  411,  373,  785,  714,  714,  780,  393,  375,
 /*   930 */   393,  380,  159,  885,  393,  389,  346,  421,  257,  645,
 /*   940 */   420,  221,  273,  411,  735,  651,  886,  411,  225,  411,
 /*   950 */   419,  191,  259,  411,   35,  782,  887,  397,  708,  180,
 /*   960 */   179,  112,   74,   74,  168,  367,  666,  366,  206,  784,
 /*   970 */   784,  786,  787,  788,  789,  790,  417,  413,  192,  242,
 /*   980 */   153,  937,   19,  280,  302,  815,  815,  825,  828,   59,
 /*   990 */    59,   60,   60,   60,   60,  277,   58,   58,   58,   58,
 /*  1000 */    57,   57,   56,   56,   56,   55,  303,  419,  381,  735,
 /*  1010 */   262,   72,  419,  933,  656,  656,  846,  323,  411,   98,
 /*  1020 */    98,  419,  195,  419,   98,   98,  735,    9,  346,  419,
 /*  1030 */   224,  241,  419,   98,   98,   98,   98,  419,  933,  189,
 /*  1040 */   419,   96,   96,  888,   96,   96,  318,  127,  382,   83,
 /*  1050 */    83,  419,   84,   84,  419,  778,  393,  410,  735,  211,
 /*  1060 */   852,  393,  370,   85,   85,  896,   86,   86,  346,  419,
 /*  1070 */   299,  419,  385,  419,  890,  411,  234,  893,   37,  735,
 /*  1080 */   411,   87,   87,   75,   75,   77,   77,  735,  897,  411,
 /*  1090 */   419,  411,  705,  183,  419,  319,  392,  411,  419,  263,
 /*  1100 */   411,  692,   88,   88,  419,  411,   89,   89,  411,   37,
 /*  1110 */    90,   90,  419,  704,  236,  300,   24,   24,  419,  411,
 /*  1120 */   400,  233,  411,  112,   91,   91,  816,  816,  826,  829,
 /*  1130 */    92,   92,  419,  693,  419,  404,  419,  411,  112,  411,
 /*  1140 */   419,  411,  344,  672,   93,   93,   79,   79,   94,   94,
 /*  1150 */   968,  419,   95,   95,  198,  419,    1,  419,  411,  656,
 /*  1160 */   656,  419,  411,   80,   80,  419,  411,  117,  117,  118,
 /*  1170 */   118,  287,  411,  119,  119,  419,  408,  102,  102,  112,
 /*  1180 */   411,  419,  345,  419,  751,  752,  411,   97,   97,  311,
 /*  1190 */   213,  776,  209,   82,   82,  105,  105,  419,  326,  419,
 /*  1200 */   411,  861,  411,  419,  411,  419,  861,  766,  411,   99,
 /*  1210 */    99,  106,  106,  315,  419,  104,  104,  116,  116,  411,
 /*  1220 */   339,  209,  227,  411,  419,  411,  111,  111,  418,  411,
 /*  1230 */   860,  314,  419,  411,  419,  860,  110,  110,  341,  209,
 /*  1240 */   845,   37,  328,  411,  109,  109,  107,  107,  419,  411,
 /*  1250 */   173,  411,  879,  356,  213,  695,   37,  419,  670,  670,
 /*  1260 */   108,  108,  419,  165,  166,  411,  419,  411,  419,  101,
 /*  1270 */   101,  411,  235,  411,  103,  103,  685,  684,  100,  100,
 /*  1280 */    73,   73,  411,  716,   39,  419,  745,  209,  252,  849,
 /*  1290 */   213,  877,  411,  791,  791,  819,  876,   76,   76,  349,
 /*  1300 */   411,  251,  411,  654,   21,  343,  350,  250,  240,  360,
 /*  1310 */   650,  244,  249,  743,  777,  261,  411,  725,  399,  850,
 /*  1320 */   265,    8,  271,  160,  657,  411,  648,  647,  649,  281,
 /*  1330 */   411,  152,  143,  223,  411,  113,  411,  132,  122,   35,
 /*  1340 */   329,  762,  863,   27,  334,  354,  232,  194,  134,  154,
 /*  1350 */   201,  202,  352,  411,  136,  193,  138,  203,  114,  243,
 /*  1360 */   297,  147,  139,  773,  363,  690,  365,  675,  115,  248,
 /*  1370 */   672,  676,  368,  881,  664,  665,  663,  689,  383,    7,
 /*  1380 */    41,   34,  402,  415,  406,   64,  910,  388,   36,  386,
 /*  1390 */   733,   10,  254,  919,  734,  732,  917,  220,  222,  256,
 /*  1400 */    68,   69,  643,  306,  895,   11,   26,  258,  184,  129,
 /*  1410 */   715,  185,  731,  267,  260,  268,  269,  312,  186,  187,
 /*  1420 */   270,  316,  130,  858,  188,  857,  855,  833,  131,  133,
 /*  1430 */   772,  125,  137,  706,  212,  135,  948,  209,  141,  866,
 /*  1440 */   140,  875,  144,  142,  333,   28,   29,   30,   31,  878,
 /*  1450 */   126,  199,  874,  197,   20,   12,  200,  155,  239,  653,
 /*  1460 */   353,  251,  204,  149,  357,   13,  361,  694,   14,  165,
 /*  1470 */   688,   32,  166,  207,  123,   33,  744,  175,  739,  805,
 /*  1480 */   803,  831,   15,  376,  208,  717,    5,  713,  176,  178,
 /*  1490 */   150,   39,  171,   37,  844,  394,  832,  797,   16,   17,
 /*  1500 */   830,  884,  156,  395,  883,  901,  401,  214,  902,  157,
 /*  1510 */   405,  835,  834,  158,  644,  804,  215,  274,  793,    3,
 /*  1520 */   414,  909,  792,   50,  640, 1226,  216,  954,  954,  820,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*    10 */    15,   16,   17,   18,   80,   20,   21,   22,   23,   24,
 /*    20 */    25,   26,   27,   28,   29,   30,   30,    5,    6,    7,
 /*    30 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*    40 */    18,   46,   20,   21,   22,   23,   24,   25,   26,   27,
 /*    50 */    28,   29,   30,    6,    7,    8,    9,   10,   11,   12,
 /*    60 */    13,   14,   15,   16,   17,   18,   71,   20,   21,   22,
 /*    70 */    23,   24,   25,   26,   27,   28,   29,   30,   24,   25,
 /*    80 */    26,   27,   28,   29,   30,  159,  160,   92,  237,  163,
 /*    90 */   162,  165,  241,    5,    6,    7,    8,    9,   10,   11,
 /*   100 */    12,   13,   14,   15,   16,   17,   18,    7,   20,   21,
 /*   110 */    22,   23,   24,   25,   26,   27,   28,   29,   30,    1,
 /*   120 */     2,   66,  203,  197,   24,   25,  200,   46,   47,  107,
 /*   130 */   108,   31,  213,   45,  162,  197,   81,   82,  200,  167,
 /*   140 */   168,  169,   42,   43,  142,  173,   46,   47,  162,  214,
 /*   150 */   222,  179,   64,   72,   20,   21,   22,   23,   24,   25,
 /*   160 */    26,   27,   28,   29,   30,   65,  231,  232,  233,   43,
 /*   170 */   115,   71,   46,   47,   74,  189,  250,  251,  231,  232,
 /*   180 */   233,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*   190 */    24,   25,   26,   27,   28,   29,   30,  142,   15,   16,
 /*   200 */    17,   18,  102,   20,   21,   22,   23,   24,   25,   26,
 /*   210 */    27,   28,   29,   30,   29,   30,  116,  117,  118,  119,
 /*   220 */   120,  121,  122,  123,  124,  125,  126,  127,  128,  129,
 /*   230 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   240 */    15,   16,   17,   18,  174,   20,   21,   22,   23,   24,
 /*   250 */    25,   26,   27,   28,   29,   30,  144,  145,  146,  147,
 /*   260 */   148,  149,  150,  151,  152,  153,  154,   97,   98,   44,
 /*   270 */    26,   27,   28,   29,   30,    5,    6,    7,    8,    9,
 /*   280 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   14,
 /*   290 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   300 */    30,   71,  162,   39,   74,   44,   45,  197,  168,  169,
 /*   310 */   200,   97,   98,  173,   44,  193,  194,  162,   43,  179,
 /*   320 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   330 */    15,   16,   17,   18,  224,   20,   21,   22,   23,   24,
 /*   340 */    25,   26,   27,   28,   29,   30,  116,  117,  118,  119,
 /*   350 */   120,  121,  242,  193,  194,   91,  142,  247,  171,   44,
 /*   360 */   162,  252,  171,  102,  103,    5,    6,    7,    8,    9,
 /*   370 */    10,   11,   12,   13,   14,   15,   16,   17,   18,  162,
 /*   380 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   390 */    30,  174,  175,  238,  239,  240,  177,  133,  172,  173,
 /*   400 */   136,   83,   84,   85,   44,  179,  156,  157,  158,  183,
 /*   410 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   420 */    15,   16,   17,   18,  186,   20,   21,   22,   23,   24,
 /*   430 */    25,   26,   27,   28,   29,   30,  238,  239,  240,   75,
 /*   440 */    76,   77,  255,  226,  227,  228,  255,  230,  174,   44,
 /*   450 */   231,  232,  233,   89,  174,    5,    6,    7,    8,    9,
 /*   460 */    10,   11,   12,   13,   14,   15,   16,   17,   18,  186,
 /*   470 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   480 */    30,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   490 */    14,   15,   16,   17,   18,  217,   20,   21,   22,   23,
 /*   500 */    24,   25,   26,   27,   28,   29,   30,    5,    6,    7,
 /*   510 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   520 */    18,  162,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   530 */    28,   29,   30,    5,    6,    7,    8,    9,   10,   11,
 /*   540 */    12,   13,   14,   15,   16,   17,   18,    7,   20,   21,
 /*   550 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   66,
 /*   560 */    46,   47,   81,   82,   24,   25,  182,  177,  184,  185,
 /*   570 */   183,   31,    7,  221,   81,   82,  162,  190,   24,   25,
 /*   580 */   162,  131,   42,   43,   44,  162,   46,   47,  174,  175,
 /*   590 */    97,   98,  174,  175,  162,   30,  115,  174,  175,  162,
 /*   600 */    46,   47,  188,  101,  221,   65,    7,  131,  115,   44,
 /*   610 */    45,   71,  253,  162,   74,  197,  102,  103,  200,  162,
 /*   620 */    92,  231,  232,  233,  162,   71,  189,   73,  183,  211,
 /*   630 */   212,  174,  175,   54,   80,  190,   82,   72,   73,   74,
 /*   640 */   197,   62,  102,  200,  230,  188,   67,  182,  230,  184,
 /*   650 */   185,  189,   87,  230,   35,  223,  116,  117,  118,  119,
 /*   660 */   120,  121,  122,  123,  124,   86,   94,   48,  128,  129,
 /*   670 */   116,   99,  118,  119,  223,  121,   43,   58,   59,   46,
 /*   680 */    47,  182,  142,  184,  185,   66,   87,  230,    5,    6,
 /*   690 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   700 */    17,   18,  214,   20,   21,   22,   23,   24,   25,   26,
 /*   710 */    27,   28,   29,   30,    5,    6,    7,    8,    9,   10,
 /*   720 */    11,   12,   13,   14,   15,   16,   17,   18,    7,   20,
 /*   730 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   740 */    46,   47,    7,  198,  199,   24,   25,   57,   43,  162,
 /*   750 */   162,   46,   31,   26,  197,  210,   66,  200,  198,  199,
 /*   760 */   162,  174,  175,   42,   43,   30,   73,   46,   47,  224,
 /*   770 */   210,   81,   82,   51,  199,   53,   71,   24,   25,   44,
 /*   780 */    45,  224,  244,   61,  197,  210,   65,  200,  162,   75,
 /*   790 */    76,   77,   71,  243,    7,   74,   43,   92,  211,   26,
 /*   800 */   174,  175,  162,   89,  247,  115,  194,   72,   73,   74,
 /*   810 */   222,   24,   25,   26,  188,   46,   47,  230,   31,   46,
 /*   820 */    47,   94,   87,  102,   71,   45,   99,   74,  197,   42,
 /*   830 */    43,  200,  142,   46,   47,  142,  196,  116,  117,  118,
 /*   840 */   119,  120,  121,  122,  123,  124,  215,  216,  162,  128,
 /*   850 */   129,  253,   65,  162,  162,  130,  230,  132,   71,  162,
 /*   860 */     7,   74,  162,  142,   46,   47,  174,  175,  162,  116,
 /*   870 */   117,  118,  119,  120,  121,  162,   45,   24,   25,  162,
 /*   880 */   188,  162,  102,  103,   31,  162,   45,  174,  175,  102,
 /*   890 */   214,  174,  175,  174,  175,   42,   43,  174,  175,   46,
 /*   900 */    47,  188,  196,  116,  117,  118,  119,  120,  121,  122,
 /*   910 */   123,  124,  143,  222,  162,  128,  129,  162,   65,  222,
 /*   920 */   102,  103,  230,   93,   71,   95,   96,   74,  211,  212,
 /*   930 */   211,  212,  101,   35,  211,  212,  162,   32,  214,   34,
 /*   940 */    35,   36,   37,  230,  162,   40,   48,  230,  196,  230,
 /*   950 */   162,  196,  214,  230,  113,  102,   58,   59,  197,  215,
 /*   960 */   216,  200,  174,  175,  162,   75,   76,   77,   78,  116,
 /*   970 */   117,  118,  119,  120,  121,  122,  123,  124,  196,   39,
 /*   980 */   201,  128,  129,    7,    8,    9,   10,   11,   12,   13,
 /*   990 */    14,   15,   16,   17,   18,   90,   20,   21,   22,   23,
 /*  1000 */    24,   25,   26,   27,   28,   29,   30,  162,    7,  162,
 /*  1010 */   162,   43,  162,   46,   46,   47,   76,  112,  230,  174,
 /*  1020 */   175,  162,  248,  162,  174,  175,  162,  202,  162,  162,
 /*  1030 */   162,   91,  162,  174,  175,  174,  175,  162,   71,  134,
 /*  1040 */   162,  174,  175,  196,  174,  175,  141,  142,   47,  174,
 /*  1050 */   175,  162,  174,  175,  162,  162,  211,  212,  162,   92,
 /*  1060 */   196,  211,  212,  174,  175,  162,  174,  175,  162,  162,
 /*  1070 */   211,  162,  211,  162,  162,  230,  136,   44,   45,  162,
 /*  1080 */   230,  174,  175,  174,  175,  174,  175,  162,  162,  230,
 /*  1090 */   162,  230,  196,   43,  162,  162,  229,  230,  162,  229,
 /*  1100 */   230,   56,  174,  175,  162,  230,  174,  175,  230,   45,
 /*  1110 */   174,  175,  162,  196,  248,  222,  174,  175,  162,  230,
 /*  1120 */   197,  196,  230,  200,  174,  175,    9,   10,   11,   12,
 /*  1130 */   174,  175,  162,   88,  162,  197,  162,  230,  200,  230,
 /*  1140 */   162,  230,    7,   79,  174,  175,  174,  175,  174,  175,
 /*  1150 */   100,  162,  174,  175,  248,  162,   43,  162,  230,   46,
 /*  1160 */    47,  162,  230,  174,  175,  162,  230,  174,  175,  174,
 /*  1170 */   175,  162,  230,  174,  175,  162,  197,  174,  175,  200,
 /*  1180 */   230,  162,   47,  162,  107,  108,  230,  174,  175,   44,
 /*  1190 */    45,   44,   45,  174,  175,  174,  175,  162,  218,  162,
 /*  1200 */   230,  116,  230,  162,  230,  162,  121,  205,  230,  174,
 /*  1210 */   175,  174,  175,   50,  162,  174,  175,  174,  175,  230,
 /*  1220 */    44,   45,  218,  230,  162,  230,  174,  175,    7,  230,
 /*  1230 */   116,   68,  162,  230,  162,  121,  174,  175,   44,   45,
 /*  1240 */    44,   45,  162,  230,  174,  175,  174,  175,  162,  230,
 /*  1250 */   162,  230,  205,   44,   45,   44,   45,  162,   46,   47,
 /*  1260 */   174,  175,  162,   81,   82,  230,  162,  230,  162,  174,
 /*  1270 */   175,  230,  249,  230,  174,  175,   73,   74,  174,  175,
 /*  1280 */   174,  175,  230,   44,   45,  162,   44,   45,   74,   44,
 /*  1290 */    45,  162,  230,   46,   47,   74,  162,  174,  175,  162,
 /*  1300 */   230,   87,  230,   44,   45,  249,  162,  177,  162,  178,
 /*  1310 */   162,  162,  162,  162,  162,  218,  230,  162,  236,  162,
 /*  1320 */   162,  202,  204,  202,  162,  230,  162,  162,  162,    9,
 /*  1330 */   230,   43,   43,  180,  230,  181,  230,  225,    5,  113,
 /*  1340 */    41,  205,  246,  130,  138,   41,  245,  166,  192,  225,
 /*  1350 */   166,  166,  180,  230,  195,  195,  195,  166,  181,  180,
 /*  1360 */    60,  192,  195,  192,   80,  187,   80,  184,  181,  180,
 /*  1370 */    79,  185,   80,  205,  176,  178,  176,  187,  105,   43,
 /*  1380 */   130,   80,  180,   43,  180,  111,  254,  106,  110,  109,
 /*  1390 */   220,   43,  219,  164,  220,  220,   36,  161,  161,  219,
 /*  1400 */   170,  170,    4,    3,   63,   43,   43,  219,   78,   43,
 /*  1410 */   209,   38,  220,  208,  219,  207,  206,   63,   72,   72,
 /*  1420 */   205,   90,   39,   44,  100,   44,   44,  234,   39,  114,
 /*  1430 */    98,   86,   80,   42,  235,  101,  140,   45,   80,  137,
 /*  1440 */   137,    1,  114,  101,  139,   14,   14,   14,   14,   47,
 /*  1450 */    86,  100,    1,  104,  135,   43,   80,   92,  133,   42,
 /*  1460 */     7,   87,   78,   43,   63,   43,   63,   44,   43,   81,
 /*  1470 */    49,   43,   82,   63,   55,   45,   47,  100,  103,   44,
 /*  1480 */    44,   44,   43,   45,  104,   44,   43,   94,   44,   44,
 /*  1490 */    43,   45,   43,   45,   44,   71,   44,  101,  104,  104,
 /*  1500 */    44,   44,   43,   45,   44,   44,   92,   45,   44,   43,
 /*  1510 */    92,   57,   44,   43,   33,   44,   43,   38,   44,   43,
 /*  1520 */   121,   44,   44,   43,    1,    0,  100,  256,  256,   74,
};
#define YY_SHIFT_USE_DFLT (1530)
#define YY_SHIFT_COUNT    (423)
#define YY_SHIFT_MIN      (-66)
#define YY_SHIFT_MAX      (1525)
static const short yy_shift_ofst[] = {
 /*     0 */   118,  540,  905,  100,  721,  853,  853,  853,  853,  853,
 /*    10 */    81,  853,  853,  853,  853,  853,  853,  853,  853,  853,
 /*    20 */    55,   81,   -5,   22,   22,  787,  853,  853,  853,  853,
 /*    30 */   853,  853,  853,  853,  853,  853,  853,  853,  853,  853,
 /*    40 */   853,  853,  853,  853,  853,  853,  853,  853,  853,  853,
 /*    50 */   853,  853,  853,  853,  853,  853,  853,  853,  853,  853,
 /*    60 */   853,  853,  853,  853,  853,  853,  554,  554,  565,  735,
 /*    70 */   493,  690,  214,   88,  225,  270,  315,  360,  405,  450,
 /*    80 */   476,  502,  528,  683,  683,  683,  683,  683,  683,  683,
 /*    90 */   683,  683,  683,  683,  683,  683,  683,  683,  683,  709,
 /*   100 */   683,   47,  976,  976,  166,  183,  183,  183,  134,   54,
 /*   110 */   244,  185,  170,  -66,  -66,  -66,   -4, 1530, 1530, 1530,
 /*   120 */   112,  112,  619,  619,  940,  126,  126,  769,  599,  694,
 /*   130 */   694,  694,  693,  694,  694,  694,  694,  694,  694,  694,
 /*   140 */   694,  694,  694,  694,  694,  694,  694,  694,  599,  694,
 /*   150 */   694,  694,  694,  170,    2,    2,    2,    2,    2, 1530,
 /*   160 */  1530,  753,  230,  230,  714,  579,  579,  261,  705,  514,
 /*   170 */   818,  898,  481,  722,  633,  773,  967,  967,  967,  968,
 /*   180 */   780, 1113,  830,  727,  694,  694,  694,  694,  694,  694,
 /*   190 */   841, 1001, 1001,  694,  694, 1135,  841,  694, 1135,  694,
 /*   200 */   694,  694,  694,  694,  694, 1064,  694, 1077,  694,  694,
 /*   210 */  1001,  694,  725,  694,  694,  572,  694,  831,  572,  694,
 /*   220 */   694,  694,  694, 1320, 1288, 1289, 1333, 1226, 1299, 1299,
 /*   230 */  1299, 1299, 1213, 1206, 1304, 1226, 1289, 1333, 1333, 1304,
 /*   240 */  1288, 1304, 1304, 1320, 1288, 1300, 1284, 1286, 1320, 1288,
 /*   250 */  1291, 1300, 1292, 1292, 1273, 1301, 1273, 1301, 1273, 1301,
 /*   260 */  1273, 1301, 1336, 1250, 1288, 1288, 1340, 1274, 1281, 1278,
 /*   270 */  1280, 1226, 1348, 1360, 1360, 1530, 1530,  264,  364,  890,
 /*   280 */  1117,  318, 1033, 1145, 1163, 1085, 1114,  275, 1147, 1176,
 /*   290 */  1194, 1196, 1209, 1211, 1212, 1182, 1203, 1045, 1214, 1239,
 /*   300 */  1242, 1245, 1221, 1247, 1050, 1259, 1398, 1400, 1341, 1362,
 /*   310 */  1363, 1330, 1366, 1354, 1373, 1346, 1347, 1331, 1383, 1379,
 /*   320 */  1324, 1381, 1382, 1389, 1332, 1315, 1345, 1334, 1352, 1391,
 /*   330 */  1302, 1392, 1303, 1296, 1305, 1358, 1440, 1342, 1328, 1431,
 /*   340 */  1432, 1433, 1434, 1364, 1402, 1349, 1351, 1451, 1319, 1412,
 /*   350 */  1376, 1325, 1365, 1417, 1453, 1374, 1384, 1420, 1401, 1422,
 /*   360 */  1423, 1425, 1403, 1388, 1421, 1390, 1428, 1410, 1419, 1435,
 /*   370 */  1436, 1437, 1430, 1393, 1439, 1441, 1443, 1438, 1377, 1444,
 /*   380 */  1445, 1429, 1380, 1447, 1375, 1446, 1394, 1448, 1395, 1450,
 /*   390 */  1452, 1456, 1396, 1446, 1457, 1424, 1458, 1460, 1449, 1454,
 /*   400 */  1461, 1459, 1414, 1462, 1464, 1466, 1418, 1462, 1468, 1470,
 /*   410 */  1471, 1473, 1474, 1476, 1477, 1399, 1478, 1480, 1455, 1426,
 /*   420 */  1479, 1481, 1523, 1525,
};
#define YY_REDUCE_USE_DFLT (-150)
#define YY_REDUCE_COUNT (276)
#define YY_REDUCE_MIN   (-149)
#define YY_REDUCE_MAX   (1237)
static const short yy_reduce_ofst[] = {
 /*     0 */   250,  418,  -74,  217,  587,  717,  719,  723,  845,  850,
 /*    10 */   -28,  414,  457,  626,  692,  859,  861,  713,  867,  870,
 /*    20 */   110,  140,  -65,  219,  390,  423,  788,  875,  878,  889,
 /*    30 */   892,  907,  909,  911,  928,  932,  936,  942,  950,  956,
 /*    40 */   970,  972,  974,  978,  989,  993,  995,  999, 1003, 1013,
 /*    50 */  1019, 1021, 1035, 1037, 1041, 1043, 1052, 1062, 1070, 1072,
 /*    60 */  1086, 1095, 1100, 1104, 1106, 1123,  155,  198,  226,  226,
 /*    70 */   545,  557,  631,  -53,  -53,  -53,  -53,  -53,  -53,  -53,
 /*    80 */   -53,  -53,  -53,  -53,  -53,  -53,  -53,  -53,  -53,  -53,
 /*    90 */   -53,  -53,  -53,  -53,  -53,  -53,  -53,  -53,  -53,  -53,
 /*   100 */   -53,  -53,  -53,  -53,  -53,  -53,  -53,  -53,  -53,  -53,
 /*   110 */   -53,  -53,  560,  384,  465,  499,  -53,  -53,  -53,  -53,
 /*   120 */   187,  191,  122,  160, -149,  432,  451,  359,  387,  -14,
 /*   130 */   640,  706,  -62,  752,  755,  782,  847,  864,  896,  917,
 /*   140 */   -72,  925,  774,  588,  866,  691,  697,  906,  445,  437,
 /*   150 */   893,  598,  462,  575,  443,  761,  923,  938,  979,  744,
 /*   160 */   -81,   70,  274,  280,  109,  238,  283,  278,  488,  352,
 /*   170 */   383,  612,  538,  550,  686,  700,  676,  724,  738,  802,
 /*   180 */   278,  848,  779,  825,  868,  903,  912,  926,  933, 1009,
 /*   190 */  1002,  980, 1004, 1080, 1088, 1023, 1047, 1129, 1056, 1134,
 /*   200 */  1137, 1144, 1146, 1148, 1149, 1131, 1150, 1130, 1151, 1152,
 /*   210 */  1097, 1155, 1082, 1157, 1158, 1119,  700, 1118, 1121, 1162,
 /*   220 */  1164, 1165, 1166, 1154, 1153, 1112, 1156, 1136, 1159, 1160,
 /*   230 */  1161, 1167, 1096, 1101, 1181, 1168, 1124, 1169, 1171, 1184,
 /*   240 */  1172, 1185, 1191, 1177, 1179, 1178, 1183, 1186, 1187, 1189,
 /*   250 */  1197, 1190, 1198, 1200, 1170, 1173, 1174, 1180, 1175, 1188,
 /*   260 */  1192, 1195, 1193, 1199, 1202, 1204, 1132, 1201, 1205, 1208,
 /*   270 */  1210, 1215, 1229, 1236, 1237, 1230, 1231,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1227, 1210, 1210, 1264, 1210, 1152, 1152, 1152, 1152, 1152,
 /*    10 */   970, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1110, 1110,
 /*    20 */  1210,  970, 1038, 1065, 1065, 1264, 1264, 1264, 1264, 1264,
 /*    30 */  1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264,
 /*    40 */  1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264,
 /*    50 */  1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264,
 /*    60 */  1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264,  970,  970,
 /*    70 */  1264, 1210, 1042, 1071, 1264, 1264, 1264, 1153, 1154, 1264,
 /*    80 */  1264, 1107, 1264, 1185, 1082, 1081, 1080, 1079, 1052, 1077,
 /*    90 */  1069, 1073, 1153, 1149, 1150, 1148, 1111, 1106, 1154, 1264,
 /*   100 */  1072, 1120, 1133, 1119, 1129, 1139, 1130, 1122, 1121, 1123,
 /*   110 */  1124, 1125, 1264,  989,  989,  989, 1126, 1136, 1135, 1134,
 /*   120 */  1264, 1264, 1264, 1264, 1159, 1264, 1264, 1264, 1009, 1264,
 /*   130 */  1264, 1264, 1210, 1264, 1264, 1264, 1264, 1264, 1264, 1264,
 /*   140 */  1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1009, 1264,
 /*   150 */  1264, 1264, 1264, 1264, 1210, 1210, 1210, 1210, 1210, 1042,
 /*   160 */  1033, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1038, 1264,
 /*   170 */  1264, 1264, 1264, 1179, 1264, 1264, 1038, 1038, 1038, 1264,
 /*   180 */  1040, 1264, 1022, 1032, 1264, 1264, 1264, 1264, 1264, 1171,
 /*   190 */  1076, 1054, 1054, 1264, 1264, 1262, 1076, 1264, 1262, 1264,
 /*   200 */  1264, 1264, 1264, 1264, 1264,  983, 1264, 1065, 1264, 1264,
 /*   210 */  1054, 1264, 1151, 1264, 1264, 1032, 1264, 1039, 1032, 1264,
 /*   220 */  1264, 1264, 1264,  995, 1160, 1087, 1012, 1076, 1019, 1019,
 /*   230 */  1019, 1019, 1184, 1183,  964, 1076, 1087, 1012, 1012,  964,
 /*   240 */  1160,  964,  964,  995, 1160, 1003,  986,  985,  995, 1160,
 /*   250 */   983, 1003, 1010, 1010, 1058, 1053, 1058, 1053, 1058, 1053,
 /*   260 */  1058, 1053, 1155, 1264, 1160, 1160, 1264, 1070, 1059, 1068,
 /*   270 */  1066, 1076, 1264, 1230, 1230, 1237, 1237, 1264, 1264, 1264,
 /*   280 */  1264, 1264, 1264, 1264, 1264, 1264, 1264, 1165, 1264, 1264,
 /*   290 */  1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264,
 /*   300 */  1264, 1264, 1264, 1264, 1093, 1264, 1264,  954, 1264, 1264,
 /*   310 */  1264, 1264, 1264, 1264, 1264, 1264, 1264, 1201, 1264, 1264,
 /*   320 */  1255, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264,
 /*   330 */  1264, 1182, 1181, 1264, 1264, 1264, 1264, 1264, 1264, 1264,
 /*   340 */  1264, 1264, 1264, 1264, 1264, 1264, 1261, 1264, 1264, 1264,
 /*   350 */  1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264,
 /*   360 */  1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264,
 /*   370 */  1264, 1264, 1264, 1024, 1264, 1264, 1264, 1243, 1264, 1264,
 /*   380 */  1264, 1264, 1264, 1264, 1264, 1067, 1264, 1060, 1264, 1264,
 /*   390 */  1264, 1264, 1264, 1250, 1264, 1264, 1264, 1264, 1264, 1264,
 /*   400 */  1264, 1264, 1264, 1212, 1264, 1264, 1264, 1211, 1264, 1264,
 /*   410 */  1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264, 1264,
 /*   420 */   958, 1264, 1264, 1264,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
    0,  /*    EXPLAIN => nothing */
   46,  /*      QUERY => ID */
   46,  /*       PLAN => ID */
    0,  /*         OR => nothing */
    0,  /*        AND => nothing */
    0,  /*        NOT => nothing */
    0,  /*         IS => nothing */
   46,  /*      MATCH => ID */
    0,  /*    LIKE_KW => nothing */
    0,  /*    BETWEEN => nothing */
    0,  /*         IN => nothing */
    0,  /*         NE => nothing */
    0,  /*         EQ => nothing */
    0,  /*         GT => nothing */
    0,  /*         LE => nothing */
    0,  /*         LT => nothing */
    0,  /*         GE => nothing */
    0,  /*     ESCAPE => nothing */
    0,  /*     BITAND => nothing */
    0,  /*      BITOR => nothing */
    0,  /*     LSHIFT => nothing */
    0,  /*     RSHIFT => nothing */
    0,  /*       PLUS => nothing */
    0,  /*      MINUS => nothing */
    0,  /*       STAR => nothing */
    0,  /*      SLASH => nothing */
    0,  /*        REM => nothing */
    0,  /*     CONCAT => nothing */
    0,  /*    COLLATE => nothing */
    0,  /*     BITNOT => nothing */
    0,  /*      START => nothing */
    0,  /* TRANSACTION => nothing */
    0,  /*     COMMIT => nothing */
    0,  /*   ROLLBACK => nothing */
    0,  /*  SAVEPOINT => nothing */
   46,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   46,  /*         IF => ID */
    0,  /*     EXISTS => nothing */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   46,  /*      ABORT => ID */
   46,  /*     ACTION => ID */
   46,  /*        ADD => ID */
   46,  /*      AFTER => ID */
   46,  /* AUTOINCREMENT => ID */
   46,  /*     BEFORE => ID */
   46,  /*    CASCADE => ID */
   46,  /*   CONFLICT => ID */
   46,  /*   DEFERRED => ID */
   46,  /*        END => ID */
   46,  /*       FAIL => ID */
   46,  /*     IGNORE => ID */
   46,  /*  INITIALLY => ID */
   46,  /*    INSTEAD => ID */
   46,  /*         NO => ID */
   46,  /*        KEY => ID */
   46,  /*     OFFSET => ID */
   46,  /*      RAISE => ID */
   46,  /*    REPLACE => ID */
   46,  /*   RESTRICT => ID */
   46,  /*     RENAME => ID */
   46,  /*   CTIME_KW => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  bool is_fallback_failed;      /* Shows if fallback failed or not */
  sqlParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "EXPLAIN",       "QUERY",       
  "PLAN",          "OR",            "AND",           "NOT",         
  "IS",            "MATCH",         "LIKE_KW",       "BETWEEN",     
  "IN",            "NE",            "EQ",            "GT",          
  "LE",            "LT",            "GE",            "ESCAPE",      
  "BITAND",        "BITOR",         "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "STAR",          "SLASH",       
  "REM",           "CONCAT",        "COLLATE",       "BITNOT",      
  "START",         "TRANSACTION",   "COMMIT",        "ROLLBACK",    
  "SAVEPOINT",     "RELEASE",       "TO",            "TABLE",       
  "CREATE",        "IF",            "EXISTS",        "LP",          
  "RP",            "COMMA",         "ID",            "INDEXED",     
  "ABORT",         "ACTION",        "ADD",           "AFTER",       
  "AUTOINCREMENT",  "BEFORE",        "CASCADE",       "CONFLICT",    
  "DEFERRED",      "END",           "FAIL",          "IGNORE",      
  "INITIALLY",     "INSTEAD",       "NO",            "KEY",         
  "OFFSET",        "RAISE",         "REPLACE",       "RESTRICT",    
  "RENAME",        "CTIME_KW",      "ANY",           "STRING",      
  "CONSTRAINT",    "DEFAULT",       "NULL",          "PRIMARY",     
  "UNIQUE",        "CHECK",         "REFERENCES",    "AUTOINCR",    
  "ON",            "UPDATE",        "DELETE",        "SIMPLE",      
  "PARTIAL",       "FULL",          "SET",           "DEFERRABLE",  
  "IMMEDIATE",     "FOREIGN",       "DROP",          "VIEW",        
  "AS",            "UNION",         "ALL",           "EXCEPT",      
  "INTERSECT",     "SELECT",        "VALUES",        "DISTINCT",    
  "DOT",           "FROM",          "JOIN_KW",       "JOIN",        
  "BY",            "USING",         "ORDER",         "ASC",         
  "DESC",          "GROUP",         "HAVING",        "LIMIT",       
  "TRUNCATE",      "WHERE",         "INTO",          "INSERT",      
  "FLOAT",         "BLOB",          "FALSE",         "TRUE",        
  "UNKNOWN",       "INTEGER",       "VARIABLE",      "CAST",        
  "TRIM",          "LEADING",       "TRAILING",      "BOTH",        
  "CHAR",          "CASE",          "WHEN",          "THEN",        
  "ELSE",          "INDEX",         "PRAGMA",        "BEGIN",       
  "TRIGGER",       "OF",            "FOR",           "EACH",        
  "ROW",           "ALTER",         "WITH",          "RECURSIVE",   
  "TEXT",          "STRING_KW",     "SCALAR",        "BOOL",        
  "BOOLEAN",       "VARBINARY",     "VARCHAR",       "NUMBER",      
  "INT",           "INTEGER_KW",    "UNSIGNED",      "error",       
  "input",         "ecmd",          "explain",       "cmdx",        
  "cmd",           "savepoint_opt",  "nm",            "create_table",
  "create_table_args",  "createkw",      "ifnotexists",   "columnlist",  
  "tcons",         "columnname",    "carglist",      "typedef",     
  "ccons",         "cconsname",     "term",          "expr",        
  "onconf",        "sortorder",     "autoinc",       "check_constraint_def",
  "eidlist_opt",   "matcharg",      "refargs",       "defer_subclause",
  "refact_update",  "refact_delete",  "refact",        "init_deferred_pred_opt",
  "sortlist",      "eidlist",       "defer_subclause_opt",  "index_onconf",
  "orconf",        "resolvetype",   "raisetype",     "ifexists",    
  "fullname",      "select",        "selectnowith",  "oneselect",   
  "with",          "multiselect_op",  "distinct",      "selcollist",  
  "from",          "where_opt",     "groupby_opt",   "having_opt",  
  "orderby_opt",   "limit_opt",     "values",        "nexprlist",   
  "exprlist",      "sclp",          "as",            "seltablist",  
  "stl_prefix",    "joinop",        "indexed_opt",   "on_opt",      
  "using_opt",     "join_nm",       "idlist",        "setlist",     
  "insert_cmd",    "idlist_opt",    "trim_operands",  "trim_from_clause",
  "trim_specification",  "expr_optional",  "type_func",     "likeop",      
  "between_op",    "in_op",         "paren_exprlist",  "case_exprlist",
  "case_else",     "uniqueflag",    "nmnum",         "minus_num",   
  "plus_num",      "trigger_decl",  "trigger_cmd_list",  "trigger_time",
  "trigger_event",  "foreach_clause",  "when_clause",   "trigger_cmd", 
  "trnm",          "tridxby",       "alter_table_start",  "alter_add_constraint",
  "unique_spec",   "wqlist",        "char_len",      "number_typedef",
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "ecmd ::= explain cmdx SEMI",
 /*   1 */ "ecmd ::= SEMI",
 /*   2 */ "explain ::= EXPLAIN",
 /*   3 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   4 */ "cmd ::= START TRANSACTION",
 /*   5 */ "cmd ::= COMMIT",
 /*   6 */ "cmd ::= ROLLBACK",
 /*   7 */ "cmd ::= SAVEPOINT nm",
 /*   8 */ "cmd ::= RELEASE savepoint_opt nm",
 /*   9 */ "cmd ::= ROLLBACK TO savepoint_opt nm",
 /*  10 */ "create_table ::= createkw TABLE ifnotexists nm",
 /*  11 */ "createkw ::= CREATE",
 /*  12 */ "ifnotexists ::=",
 /*  13 */ "ifnotexists ::= IF NOT EXISTS",
 /*  14 */ "create_table_args ::= LP columnlist RP",
 /*  15 */ "columnname ::= nm typedef",
 /*  16 */ "nm ::= ID|INDEXED",
 /*  17 */ "cconsname ::= CONSTRAINT nm",
 /*  18 */ "cconsname ::=",
 /*  19 */ "ccons ::= DEFAULT term",
 /*  20 */ "ccons ::= DEFAULT LP expr RP",
 /*  21 */ "ccons ::= DEFAULT PLUS term",
 /*  22 */ "ccons ::= DEFAULT MINUS term",
 /*  23 */ "ccons ::= NULL onconf",
 /*  24 */ "ccons ::= NOT NULL onconf",
 /*  25 */ "ccons ::= cconsname PRIMARY KEY sortorder autoinc",
 /*  26 */ "ccons ::= cconsname UNIQUE",
 /*  27 */ "check_constraint_def ::= cconsname CHECK LP expr RP",
 /*  28 */ "ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs",
 /*  29 */ "ccons ::= defer_subclause",
 /*  30 */ "ccons ::= COLLATE ID|INDEXED",
 /*  31 */ "autoinc ::=",
 /*  32 */ "autoinc ::= AUTOINCR",
 /*  33 */ "refargs ::= refact_update",
 /*  34 */ "refargs ::= refact_delete",
 /*  35 */ "refargs ::= refact_delete refact_update",
 /*  36 */ "refargs ::= refact_update refact_delete",
 /*  37 */ "refargs ::=",
 /*  38 */ "refact_update ::= ON UPDATE refact",
 /*  39 */ "refact_delete ::= ON DELETE refact",
 /*  40 */ "matcharg ::= MATCH SIMPLE",
 /*  41 */ "matcharg ::= MATCH PARTIAL",
 /*  42 */ "matcharg ::= MATCH FULL",
 /*  43 */ "matcharg ::=",
 /*  44 */ "refact ::= SET NULL",
 /*  45 */ "refact ::= SET DEFAULT",
 /*  46 */ "refact ::= CASCADE",
 /*  47 */ "refact ::= RESTRICT",
 /*  48 */ "refact ::= NO ACTION",
 /*  49 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  50 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  51 */ "init_deferred_pred_opt ::=",
 /*  52 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  53 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  54 */ "tcons ::= cconsname PRIMARY KEY LP sortlist autoinc RP",
 /*  55 */ "tcons ::= cconsname UNIQUE LP sortlist RP",
 /*  56 */ "tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /*  57 */ "defer_subclause_opt ::=",
 /*  58 */ "onconf ::=",
 /*  59 */ "onconf ::= ON CONFLICT resolvetype",
 /*  60 */ "orconf ::=",
 /*  61 */ "orconf ::= OR resolvetype",
 /*  62 */ "resolvetype ::= IGNORE",
 /*  63 */ "resolvetype ::= REPLACE",
 /*  64 */ "cmd ::= DROP TABLE ifexists fullname",
 /*  65 */ "cmd ::= DROP VIEW ifexists fullname",
 /*  66 */ "ifexists ::= IF EXISTS",
 /*  67 */ "ifexists ::=",
 /*  68 */ "cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select",
 /*  69 */ "cmd ::= select",
 /*  70 */ "select ::= with selectnowith",
 /*  71 */ "selectnowith ::= selectnowith multiselect_op oneselect",
 /*  72 */ "multiselect_op ::= UNION",
 /*  73 */ "multiselect_op ::= UNION ALL",
 /*  74 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /*  75 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /*  76 */ "values ::= VALUES LP nexprlist RP",
 /*  77 */ "values ::= values COMMA LP exprlist RP",
 /*  78 */ "distinct ::= DISTINCT",
 /*  79 */ "distinct ::= ALL",
 /*  80 */ "distinct ::=",
 /*  81 */ "sclp ::=",
 /*  82 */ "selcollist ::= sclp expr as",
 /*  83 */ "selcollist ::= sclp STAR",
 /*  84 */ "selcollist ::= sclp nm DOT STAR",
 /*  85 */ "as ::= AS nm",
 /*  86 */ "as ::=",
 /*  87 */ "from ::=",
 /*  88 */ "from ::= FROM seltablist",
 /*  89 */ "stl_prefix ::= seltablist joinop",
 /*  90 */ "stl_prefix ::=",
 /*  91 */ "seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt",
 /*  92 */ "seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt",
 /*  93 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /*  94 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /*  95 */ "fullname ::= nm",
 /*  96 */ "joinop ::= COMMA|JOIN",
 /*  97 */ "joinop ::= JOIN_KW JOIN",
 /*  98 */ "joinop ::= JOIN_KW join_nm JOIN",
 /*  99 */ "joinop ::= JOIN_KW join_nm join_nm JOIN",
 /* 100 */ "on_opt ::= ON expr",
 /* 101 */ "on_opt ::=",
 /* 102 */ "indexed_opt ::=",
 /* 103 */ "indexed_opt ::= INDEXED BY nm",
 /* 104 */ "indexed_opt ::= NOT INDEXED",
 /* 105 */ "using_opt ::= USING LP idlist RP",
 /* 106 */ "using_opt ::=",
 /* 107 */ "orderby_opt ::=",
 /* 108 */ "orderby_opt ::= ORDER BY sortlist",
 /* 109 */ "sortlist ::= sortlist COMMA expr sortorder",
 /* 110 */ "sortlist ::= expr sortorder",
 /* 111 */ "sortorder ::= ASC",
 /* 112 */ "sortorder ::= DESC",
 /* 113 */ "sortorder ::=",
 /* 114 */ "groupby_opt ::=",
 /* 115 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 116 */ "having_opt ::=",
 /* 117 */ "having_opt ::= HAVING expr",
 /* 118 */ "limit_opt ::=",
 /* 119 */ "limit_opt ::= LIMIT expr",
 /* 120 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 121 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 122 */ "cmd ::= with DELETE FROM fullname indexed_opt where_opt",
 /* 123 */ "cmd ::= TRUNCATE TABLE fullname",
 /* 124 */ "where_opt ::=",
 /* 125 */ "where_opt ::= WHERE expr",
 /* 126 */ "cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 127 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 128 */ "setlist ::= setlist COMMA LP idlist RP EQ expr",
 /* 129 */ "setlist ::= nm EQ expr",
 /* 130 */ "setlist ::= LP idlist RP EQ expr",
 /* 131 */ "cmd ::= with insert_cmd INTO fullname idlist_opt select",
 /* 132 */ "cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES",
 /* 133 */ "insert_cmd ::= INSERT orconf",
 /* 134 */ "insert_cmd ::= REPLACE",
 /* 135 */ "idlist_opt ::=",
 /* 136 */ "idlist_opt ::= LP idlist RP",
 /* 137 */ "idlist ::= idlist COMMA nm",
 /* 138 */ "idlist ::= nm",
 /* 139 */ "expr ::= LP expr RP",
 /* 140 */ "term ::= NULL",
 /* 141 */ "expr ::= ID|INDEXED",
 /* 142 */ "expr ::= JOIN_KW",
 /* 143 */ "expr ::= nm DOT nm",
 /* 144 */ "term ::= FLOAT|BLOB",
 /* 145 */ "term ::= STRING",
 /* 146 */ "term ::= FALSE",
 /* 147 */ "term ::= TRUE",
 /* 148 */ "term ::= UNKNOWN",
 /* 149 */ "term ::= INTEGER",
 /* 150 */ "expr ::= VARIABLE",
 /* 151 */ "expr ::= expr COLLATE ID|INDEXED",
 /* 152 */ "expr ::= CAST LP expr AS typedef RP",
 /* 153 */ "expr ::= TRIM LP trim_operands RP",
 /* 154 */ "trim_operands ::= trim_from_clause expr",
 /* 155 */ "trim_operands ::= expr",
 /* 156 */ "trim_from_clause ::= expr FROM",
 /* 157 */ "trim_from_clause ::= trim_specification expr_optional FROM",
 /* 158 */ "expr_optional ::=",
 /* 159 */ "expr_optional ::= expr",
 /* 160 */ "trim_specification ::= LEADING",
 /* 161 */ "trim_specification ::= TRAILING",
 /* 162 */ "trim_specification ::= BOTH",
 /* 163 */ "expr ::= ID|INDEXED LP distinct exprlist RP",
 /* 164 */ "expr ::= type_func LP distinct exprlist RP",
 /* 165 */ "expr ::= ID|INDEXED LP STAR RP",
 /* 166 */ "expr ::= LP nexprlist COMMA expr RP",
 /* 167 */ "expr ::= expr AND expr",
 /* 168 */ "expr ::= expr OR expr",
 /* 169 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 170 */ "expr ::= expr EQ|NE expr",
 /* 171 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 172 */ "expr ::= expr PLUS|MINUS expr",
 /* 173 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 174 */ "expr ::= expr CONCAT expr",
 /* 175 */ "likeop ::= LIKE_KW|MATCH",
 /* 176 */ "likeop ::= NOT LIKE_KW|MATCH",
 /* 177 */ "expr ::= expr likeop expr",
 /* 178 */ "expr ::= expr likeop expr ESCAPE expr",
 /* 179 */ "expr ::= expr IS NULL",
 /* 180 */ "expr ::= expr IS NOT NULL",
 /* 181 */ "expr ::= NOT expr",
 /* 182 */ "expr ::= BITNOT expr",
 /* 183 */ "expr ::= MINUS expr",
 /* 184 */ "expr ::= PLUS expr",
 /* 185 */ "between_op ::= BETWEEN",
 /* 186 */ "between_op ::= NOT BETWEEN",
 /* 187 */ "expr ::= expr between_op expr AND expr",
 /* 188 */ "in_op ::= IN",
 /* 189 */ "in_op ::= NOT IN",
 /* 190 */ "expr ::= expr in_op LP exprlist RP",
 /* 191 */ "expr ::= LP select RP",
 /* 192 */ "expr ::= expr in_op LP select RP",
 /* 193 */ "expr ::= expr in_op nm paren_exprlist",
 /* 194 */ "expr ::= EXISTS LP select RP",
 /* 195 */ "expr ::= CASE expr_optional case_exprlist case_else END",
 /* 196 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 197 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 198 */ "case_else ::= ELSE expr",
 /* 199 */ "case_else ::=",
 /* 200 */ "exprlist ::=",
 /* 201 */ "nexprlist ::= nexprlist COMMA expr",
 /* 202 */ "nexprlist ::= expr",
 /* 203 */ "paren_exprlist ::=",
 /* 204 */ "paren_exprlist ::= LP exprlist RP",
 /* 205 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP",
 /* 206 */ "uniqueflag ::= UNIQUE",
 /* 207 */ "uniqueflag ::=",
 /* 208 */ "eidlist_opt ::=",
 /* 209 */ "eidlist_opt ::= LP eidlist RP",
 /* 210 */ "eidlist ::= eidlist COMMA nm",
 /* 211 */ "eidlist ::= nm",
 /* 212 */ "cmd ::= DROP INDEX ifexists nm ON fullname",
 /* 213 */ "cmd ::= PRAGMA nm",
 /* 214 */ "cmd ::= PRAGMA nm EQ nmnum",
 /* 215 */ "cmd ::= PRAGMA nm LP nmnum RP",
 /* 216 */ "cmd ::= PRAGMA nm EQ minus_num",
 /* 217 */ "cmd ::= PRAGMA nm LP minus_num RP",
 /* 218 */ "cmd ::= PRAGMA nm LP nm DOT nm RP",
 /* 219 */ "cmd ::= PRAGMA",
 /* 220 */ "plus_num ::= PLUS INTEGER|FLOAT",
 /* 221 */ "minus_num ::= MINUS INTEGER|FLOAT",
 /* 222 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 223 */ "trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 224 */ "trigger_time ::= BEFORE",
 /* 225 */ "trigger_time ::= AFTER",
 /* 226 */ "trigger_time ::= INSTEAD OF",
 /* 227 */ "trigger_time ::=",
 /* 228 */ "trigger_event ::= DELETE|INSERT",
 /* 229 */ "trigger_event ::= UPDATE",
 /* 230 */ "trigger_event ::= UPDATE OF idlist",
 /* 231 */ "foreach_clause ::=",
 /* 232 */ "when_clause ::=",
 /* 233 */ "when_clause ::= WHEN expr",
 /* 234 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 235 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 236 */ "trnm ::= nm DOT nm",
 /* 237 */ "tridxby ::= INDEXED BY nm",
 /* 238 */ "tridxby ::= NOT INDEXED",
 /* 239 */ "trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt",
 /* 240 */ "trigger_cmd ::= insert_cmd INTO trnm idlist_opt select",
 /* 241 */ "trigger_cmd ::= DELETE FROM trnm tridxby where_opt",
 /* 242 */ "trigger_cmd ::= select",
 /* 243 */ "expr ::= RAISE LP IGNORE RP",
 /* 244 */ "expr ::= RAISE LP raisetype COMMA STRING RP",
 /* 245 */ "raisetype ::= ROLLBACK",
 /* 246 */ "raisetype ::= ABORT",
 /* 247 */ "raisetype ::= FAIL",
 /* 248 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 249 */ "alter_table_start ::= ALTER TABLE fullname",
 /* 250 */ "alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm",
 /* 251 */ "cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /* 252 */ "cmd ::= alter_add_constraint CHECK LP expr RP",
 /* 253 */ "cmd ::= alter_add_constraint unique_spec LP sortlist RP",
 /* 254 */ "unique_spec ::= UNIQUE",
 /* 255 */ "unique_spec ::= PRIMARY KEY",
 /* 256 */ "cmd ::= alter_table_start RENAME TO nm",
 /* 257 */ "cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm",
 /* 258 */ "with ::=",
 /* 259 */ "with ::= WITH wqlist",
 /* 260 */ "with ::= WITH RECURSIVE wqlist",
 /* 261 */ "wqlist ::= nm eidlist_opt AS LP select RP",
 /* 262 */ "wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP",
 /* 263 */ "typedef ::= TEXT",
 /* 264 */ "typedef ::= STRING_KW",
 /* 265 */ "typedef ::= SCALAR",
 /* 266 */ "typedef ::= BOOL",
 /* 267 */ "typedef ::= BOOLEAN",
 /* 268 */ "typedef ::= VARBINARY",
 /* 269 */ "char_len ::= LP INTEGER RP",
 /* 270 */ "typedef ::= VARCHAR char_len",
 /* 271 */ "number_typedef ::= NUMBER",
 /* 272 */ "number_typedef ::= INT|INTEGER_KW",
 /* 273 */ "number_typedef ::= UNSIGNED",
 /* 274 */ "input ::= ecmd",
 /* 275 */ "explain ::=",
 /* 276 */ "cmdx ::= cmd",
 /* 277 */ "savepoint_opt ::= SAVEPOINT",
 /* 278 */ "savepoint_opt ::=",
 /* 279 */ "cmd ::= create_table create_table_args",
 /* 280 */ "columnlist ::= columnlist COMMA tcons",
 /* 281 */ "columnlist ::= columnlist COMMA columnname carglist",
 /* 282 */ "columnlist ::= columnname carglist",
 /* 283 */ "columnlist ::= tcons",
 /* 284 */ "carglist ::= carglist ccons",
 /* 285 */ "carglist ::=",
 /* 286 */ "ccons ::= check_constraint_def",
 /* 287 */ "tcons ::= check_constraint_def",
 /* 288 */ "defer_subclause_opt ::= defer_subclause",
 /* 289 */ "resolvetype ::= raisetype",
 /* 290 */ "selectnowith ::= oneselect",
 /* 291 */ "oneselect ::= values",
 /* 292 */ "sclp ::= selcollist COMMA",
 /* 293 */ "as ::= ID|STRING",
 /* 294 */ "join_nm ::= ID|INDEXED",
 /* 295 */ "join_nm ::= JOIN_KW",
 /* 296 */ "expr ::= term",
 /* 297 */ "type_func ::= CHAR",
 /* 298 */ "exprlist ::= nexprlist",
 /* 299 */ "nmnum ::= plus_num",
 /* 300 */ "nmnum ::= STRING",
 /* 301 */ "nmnum ::= TRUE",
 /* 302 */ "nmnum ::= FALSE",
 /* 303 */ "nmnum ::= nm",
 /* 304 */ "nmnum ::= ON",
 /* 305 */ "nmnum ::= DELETE",
 /* 306 */ "nmnum ::= DEFAULT",
 /* 307 */ "plus_num ::= INTEGER|FLOAT",
 /* 308 */ "foreach_clause ::= FOR EACH ROW",
 /* 309 */ "trnm ::= nm",
 /* 310 */ "tridxby ::=",
 /* 311 */ "typedef ::= number_typedef",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to sqlParserAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlParser and sqlParserFree.
*/
void *sqlParserAlloc(void *(*mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
    pParser->is_fallback_failed = false;
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
    case 174: /* term */
    case 175: /* expr */
{
#line 888 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy150).pExpr, false);
#line 1562 "parse.c"
}
      break;
    case 180: /* eidlist_opt */
    case 188: /* sortlist */
    case 189: /* eidlist */
    case 203: /* selcollist */
    case 206: /* groupby_opt */
    case 208: /* orderby_opt */
    case 211: /* nexprlist */
    case 212: /* exprlist */
    case 213: /* sclp */
    case 223: /* setlist */
    case 234: /* paren_exprlist */
    case 235: /* case_exprlist */
{
#line 1442 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy402));
#line 1580 "parse.c"
}
      break;
    case 196: /* fullname */
    case 204: /* from */
    case 215: /* seltablist */
    case 216: /* stl_prefix */
{
#line 672 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
sqlSrcListDelete(pParse->db, (yypminor->yy3));
#line 1590 "parse.c"
}
      break;
    case 197: /* select */
    case 198: /* selectnowith */
    case 199: /* oneselect */
    case 210: /* values */
{
#line 434 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
sql_select_delete(pParse->db, (yypminor->yy43));
#line 1600 "parse.c"
}
      break;
    case 200: /* with */
    case 253: /* wqlist */
{
#line 1732 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
sqlWithDelete(pParse->db, (yypminor->yy4));
#line 1608 "parse.c"
}
      break;
    case 205: /* where_opt */
    case 207: /* having_opt */
    case 219: /* on_opt */
    case 236: /* case_else */
    case 246: /* when_clause */
{
#line 797 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy2), false);
#line 1619 "parse.c"
}
      break;
    case 220: /* using_opt */
    case 222: /* idlist */
    case 225: /* idlist_opt */
{
#line 715 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy272));
#line 1628 "parse.c"
}
      break;
    case 226: /* trim_operands */
    case 227: /* trim_from_clause */
{
#line 1059 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy215));
#line 1636 "parse.c"
}
      break;
    case 229: /* expr_optional */
{
#line 1090 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy87), false);
#line 1643 "parse.c"
}
      break;
    case 242: /* trigger_cmd_list */
    case 247: /* trigger_cmd */
{
#line 1560 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
sqlDeleteTriggerStep(pParse->db, (yypminor->yy347));
#line 1651 "parse.c"
}
      break;
    case 244: /* trigger_event */
{
#line 1542 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy338).b);
#line 1658 "parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void sqlParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback = -1;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      } else if ( iFallback==0 ) {
        pParser->is_fallback_failed = true;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   sqlParserARG_FETCH;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
#line 43 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"

  diag_set(ClientError, ER_SQL_STACK_OVERFLOW);
  pParse->is_aborted = true;
#line 1834 "parse.c"
/******** End %stack_overflow code ********************************************/
   sqlParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  sqlParserTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yypParser->yytos--;
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yypParser->yytos--;
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 157, 3 },
  { 157, 1 },
  { 158, 1 },
  { 158, 3 },
  { 160, 2 },
  { 160, 1 },
  { 160, 1 },
  { 160, 2 },
  { 160, 3 },
  { 160, 4 },
  { 163, 4 },
  { 165, 1 },
  { 166, 0 },
  { 166, 3 },
  { 164, 3 },
  { 169, 2 },
  { 162, 1 },
  { 173, 2 },
  { 173, 0 },
  { 172, 2 },
  { 172, 4 },
  { 172, 3 },
  { 172, 3 },
  { 172, 2 },
  { 172, 3 },
  { 172, 5 },
  { 172, 2 },
  { 179, 5 },
  { 172, 6 },
  { 172, 1 },
  { 172, 2 },
  { 178, 0 },
  { 178, 1 },
  { 182, 1 },
  { 182, 1 },
  { 182, 2 },
  { 182, 2 },
  { 182, 0 },
  { 184, 3 },
  { 185, 3 },
  { 181, 2 },
  { 181, 2 },
  { 181, 2 },
  { 181, 0 },
  { 186, 2 },
  { 186, 2 },
  { 186, 1 },
  { 186, 1 },
  { 186, 2 },
  { 183, 3 },
  { 183, 2 },
  { 187, 0 },
  { 187, 2 },
  { 187, 2 },
  { 168, 7 },
  { 168, 5 },
  { 168, 12 },
  { 190, 0 },
  { 176, 0 },
  { 176, 3 },
  { 192, 0 },
  { 192, 2 },
  { 193, 1 },
  { 193, 1 },
  { 160, 4 },
  { 160, 4 },
  { 195, 2 },
  { 195, 0 },
  { 160, 7 },
  { 160, 1 },
  { 197, 2 },
  { 198, 3 },
  { 201, 1 },
  { 201, 2 },
  { 201, 1 },
  { 199, 9 },
  { 210, 4 },
  { 210, 5 },
  { 202, 1 },
  { 202, 1 },
  { 202, 0 },
  { 213, 0 },
  { 203, 3 },
  { 203, 2 },
  { 203, 4 },
  { 214, 2 },
  { 214, 0 },
  { 204, 0 },
  { 204, 2 },
  { 216, 2 },
  { 216, 0 },
  { 215, 6 },
  { 215, 8 },
  { 215, 7 },
  { 215, 7 },
  { 196, 1 },
  { 217, 1 },
  { 217, 2 },
  { 217, 3 },
  { 217, 4 },
  { 219, 2 },
  { 219, 0 },
  { 218, 0 },
  { 218, 3 },
  { 218, 2 },
  { 220, 4 },
  { 220, 0 },
  { 208, 0 },
  { 208, 3 },
  { 188, 4 },
  { 188, 2 },
  { 177, 1 },
  { 177, 1 },
  { 177, 0 },
  { 206, 0 },
  { 206, 3 },
  { 207, 0 },
  { 207, 2 },
  { 209, 0 },
  { 209, 2 },
  { 209, 4 },
  { 209, 4 },
  { 160, 6 },
  { 160, 3 },
  { 205, 0 },
  { 205, 2 },
  { 160, 8 },
  { 223, 5 },
  { 223, 7 },
  { 223, 3 },
  { 223, 5 },
  { 160, 6 },
  { 160, 7 },
  { 224, 2 },
  { 224, 1 },
  { 225, 0 },
  { 225, 3 },
  { 222, 3 },
  { 222, 1 },
  { 175, 3 },
  { 174, 1 },
  { 175, 1 },
  { 175, 1 },
  { 175, 3 },
  { 174, 1 },
  { 174, 1 },
  { 174, 1 },
  { 174, 1 },
  { 174, 1 },
  { 174, 1 },
  { 175, 1 },
  { 175, 3 },
  { 175, 6 },
  { 175, 4 },
  { 226, 2 },
  { 226, 1 },
  { 227, 2 },
  { 227, 3 },
  { 229, 0 },
  { 229, 1 },
  { 228, 1 },
  { 228, 1 },
  { 228, 1 },
  { 175, 5 },
  { 175, 5 },
  { 175, 4 },
  { 175, 5 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 231, 1 },
  { 231, 2 },
  { 175, 3 },
  { 175, 5 },
  { 175, 3 },
  { 175, 4 },
  { 175, 2 },
  { 175, 2 },
  { 175, 2 },
  { 175, 2 },
  { 232, 1 },
  { 232, 2 },
  { 175, 5 },
  { 233, 1 },
  { 233, 2 },
  { 175, 5 },
  { 175, 3 },
  { 175, 5 },
  { 175, 4 },
  { 175, 4 },
  { 175, 5 },
  { 235, 5 },
  { 235, 4 },
  { 236, 2 },
  { 236, 0 },
  { 212, 0 },
  { 211, 3 },
  { 211, 1 },
  { 234, 0 },
  { 234, 3 },
  { 160, 10 },
  { 237, 1 },
  { 237, 0 },
  { 180, 0 },
  { 180, 3 },
  { 189, 3 },
  { 189, 1 },
  { 160, 6 },
  { 160, 2 },
  { 160, 4 },
  { 160, 5 },
  { 160, 4 },
  { 160, 5 },
  { 160, 7 },
  { 160, 1 },
  { 240, 2 },
  { 239, 2 },
  { 160, 5 },
  { 241, 9 },
  { 243, 1 },
  { 243, 1 },
  { 243, 2 },
  { 243, 0 },
  { 244, 1 },
  { 244, 1 },
  { 244, 3 },
  { 245, 0 },
  { 246, 0 },
  { 246, 2 },
  { 242, 3 },
  { 242, 2 },
  { 248, 3 },
  { 249, 3 },
  { 249, 2 },
  { 247, 7 },
  { 247, 5 },
  { 247, 5 },
  { 247, 1 },
  { 175, 4 },
  { 175, 6 },
  { 194, 1 },
  { 194, 1 },
  { 194, 1 },
  { 160, 4 },
  { 250, 3 },
  { 251, 4 },
  { 160, 12 },
  { 160, 5 },
  { 160, 5 },
  { 252, 1 },
  { 252, 2 },
  { 160, 4 },
  { 160, 6 },
  { 200, 0 },
  { 200, 2 },
  { 200, 3 },
  { 253, 6 },
  { 253, 8 },
  { 171, 1 },
  { 171, 1 },
  { 171, 1 },
  { 171, 1 },
  { 171, 1 },
  { 171, 1 },
  { 254, 3 },
  { 171, 2 },
  { 255, 1 },
  { 255, 1 },
  { 255, 1 },
  { 156, 1 },
  { 158, 0 },
  { 159, 1 },
  { 161, 1 },
  { 161, 0 },
  { 160, 2 },
  { 167, 3 },
  { 167, 4 },
  { 167, 2 },
  { 167, 1 },
  { 170, 2 },
  { 170, 0 },
  { 172, 1 },
  { 168, 1 },
  { 190, 1 },
  { 193, 1 },
  { 198, 1 },
  { 199, 1 },
  { 213, 2 },
  { 214, 1 },
  { 221, 1 },
  { 221, 1 },
  { 175, 1 },
  { 230, 1 },
  { 212, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 240, 1 },
  { 245, 3 },
  { 248, 1 },
  { 249, 0 },
  { 171, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlParserARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* ecmd ::= explain cmdx SEMI */
#line 122 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
	if (!pParse->parse_only)
		sql_finish_coding(pParse);
}
#line 2289 "parse.c"
        break;
      case 1: /* ecmd ::= SEMI */
#line 126 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_STATEMENT_EMPTY);
  pParse->is_aborted = true;
}
#line 2297 "parse.c"
        break;
      case 2: /* explain ::= EXPLAIN */
#line 131 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ pParse->explain = 1; }
#line 2302 "parse.c"
        break;
      case 3: /* explain ::= EXPLAIN QUERY PLAN */
#line 132 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ pParse->explain = 2; }
#line 2307 "parse.c"
        break;
      case 4: /* cmd ::= START TRANSACTION */
#line 162 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{sql_transaction_begin(pParse);}
#line 2312 "parse.c"
        break;
      case 5: /* cmd ::= COMMIT */
#line 163 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{sql_transaction_commit(pParse);}
#line 2317 "parse.c"
        break;
      case 6: /* cmd ::= ROLLBACK */
#line 164 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{sql_transaction_rollback(pParse);}
#line 2322 "parse.c"
        break;
      case 7: /* cmd ::= SAVEPOINT nm */
#line 168 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2329 "parse.c"
        break;
      case 8: /* cmd ::= RELEASE savepoint_opt nm */
#line 171 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2336 "parse.c"
        break;
      case 9: /* cmd ::= ROLLBACK TO savepoint_opt nm */
#line 174 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2343 "parse.c"
        break;
      case 10: /* create_table ::= createkw TABLE ifnotexists nm */
#line 181 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  create_table_def_init(&pParse->create_table_def, &yymsp[0].minor.yy0, yymsp[-1].minor.yy348);
  pParse->create_table_def.new_space = sqlStartTable(pParse, &yymsp[0].minor.yy0);
  pParse->initiateTTrans = true;
}
#line 2352 "parse.c"
        break;
      case 11: /* createkw ::= CREATE */
#line 186 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{disableLookaside(pParse);}
#line 2357 "parse.c"
        break;
      case 12: /* ifnotexists ::= */
      case 31: /* autoinc ::= */ yytestcase(yyruleno==31);
      case 51: /* init_deferred_pred_opt ::= */ yytestcase(yyruleno==51);
      case 57: /* defer_subclause_opt ::= */ yytestcase(yyruleno==57);
      case 67: /* ifexists ::= */ yytestcase(yyruleno==67);
      case 80: /* distinct ::= */ yytestcase(yyruleno==80);
#line 189 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy348 = 0;}
#line 2367 "parse.c"
        break;
      case 13: /* ifnotexists ::= IF NOT EXISTS */
#line 190 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-2].minor.yy348 = 1;}
#line 2372 "parse.c"
        break;
      case 14: /* create_table_args ::= LP columnlist RP */
#line 192 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  sqlEndTable(pParse);
}
#line 2379 "parse.c"
        break;
      case 15: /* columnname ::= nm typedef */
#line 210 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{sqlAddColumn(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy434);}
#line 2384 "parse.c"
        break;
      case 16: /* nm ::= ID|INDEXED */
#line 245 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  if(yymsp[0].minor.yy0.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z);
    pParse->is_aborted = true;
  }
}
#line 2394 "parse.c"
        break;
      case 17: /* cconsname ::= CONSTRAINT nm */
#line 258 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-1].minor.yy167 = yymsp[0].minor.yy0; }
#line 2399 "parse.c"
        break;
      case 18: /* cconsname ::= */
#line 259 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[1].minor.yy167 = Token_nil; }
#line 2404 "parse.c"
        break;
      case 19: /* ccons ::= DEFAULT term */
      case 21: /* ccons ::= DEFAULT PLUS term */ yytestcase(yyruleno==21);
#line 260 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[0].minor.yy150);}
#line 2410 "parse.c"
        break;
      case 20: /* ccons ::= DEFAULT LP expr RP */
#line 261 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[-1].minor.yy150);}
#line 2415 "parse.c"
        break;
      case 22: /* ccons ::= DEFAULT MINUS term */
#line 263 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  ExprSpan v;
  v.pExpr = sqlPExpr(pParse, TK_UMINUS, yymsp[0].minor.yy150.pExpr, 0);
  v.zStart = yymsp[-1].minor.yy0.z;
  v.zEnd = yymsp[0].minor.yy150.zEnd;
  sqlAddDefaultValue(pParse,&v);
}
#line 2426 "parse.c"
        break;
      case 23: /* ccons ::= NULL onconf */
#line 274 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
    sql_column_add_nullable_action(pParse, ON_CONFLICT_ACTION_NONE);
    /* Trigger nullability mismatch error if required. */
    if (yymsp[0].minor.yy348 != ON_CONFLICT_ACTION_ABORT)
        sql_column_add_nullable_action(pParse, yymsp[0].minor.yy348);
}
#line 2436 "parse.c"
        break;
      case 24: /* ccons ::= NOT NULL onconf */
#line 280 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{sql_column_add_nullable_action(pParse, yymsp[0].minor.yy348);}
#line 2441 "parse.c"
        break;
      case 25: /* ccons ::= cconsname PRIMARY KEY sortorder autoinc */
#line 281 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  pParse->create_table_def.has_autoinc = yymsp[0].minor.yy348;
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-4].minor.yy167, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, yymsp[-1].minor.yy348, false);
  sqlAddPrimaryKey(pParse);
}
#line 2451 "parse.c"
        break;
      case 26: /* ccons ::= cconsname UNIQUE */
#line 287 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-1].minor.yy167, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2461 "parse.c"
        break;
      case 27: /* check_constraint_def ::= cconsname CHECK LP expr RP */
#line 296 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  create_ck_def_init(&pParse->create_ck_def, NULL, &yymsp[-4].minor.yy167, &yymsp[-1].minor.yy150);
  sql_create_check_contraint(pParse);
}
#line 2469 "parse.c"
        break;
      case 28: /* ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs */
#line 301 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-5].minor.yy167, NULL, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy402, yymsp[-1].minor.yy348, yymsp[0].minor.yy348,
                     false);
  sql_create_foreign_key(pParse);
}
#line 2478 "parse.c"
        break;
      case 29: /* ccons ::= defer_subclause */
#line 306 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{fk_constraint_change_defer_mode(pParse, yymsp[0].minor.yy348);}
#line 2483 "parse.c"
        break;
      case 30: /* ccons ::= COLLATE ID|INDEXED */
#line 307 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{sqlAddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2488 "parse.c"
        break;
      case 32: /* autoinc ::= AUTOINCR */
#line 312 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = 1;}
#line 2493 "parse.c"
        break;
      case 33: /* refargs ::= refact_update */
#line 320 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yylhsminor.yy348 = (yymsp[0].minor.yy348 << 8); }
#line 2498 "parse.c"
  yymsp[0].minor.yy348 = yylhsminor.yy348;
        break;
      case 34: /* refargs ::= refact_delete */
#line 321 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yylhsminor.yy348 = yymsp[0].minor.yy348; }
#line 2504 "parse.c"
  yymsp[0].minor.yy348 = yylhsminor.yy348;
        break;
      case 35: /* refargs ::= refact_delete refact_update */
#line 322 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yylhsminor.yy348 = (yymsp[0].minor.yy348 << 8) | (yymsp[-1].minor.yy348) ; }
#line 2510 "parse.c"
  yymsp[-1].minor.yy348 = yylhsminor.yy348;
        break;
      case 36: /* refargs ::= refact_update refact_delete */
#line 323 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yylhsminor.yy348 = (yymsp[-1].minor.yy348 << 8) | (yymsp[0].minor.yy348) ; }
#line 2516 "parse.c"
  yymsp[-1].minor.yy348 = yylhsminor.yy348;
        break;
      case 37: /* refargs ::= */
#line 324 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[1].minor.yy348 = 0; }
#line 2522 "parse.c"
        break;
      case 38: /* refact_update ::= ON UPDATE refact */
      case 39: /* refact_delete ::= ON DELETE refact */ yytestcase(yyruleno==39);
#line 327 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-2].minor.yy348 = yymsp[0].minor.yy348; }
#line 2528 "parse.c"
        break;
      case 40: /* matcharg ::= MATCH SIMPLE */
#line 332 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-1].minor.yy348 = FKEY_MATCH_SIMPLE; }
#line 2533 "parse.c"
        break;
      case 41: /* matcharg ::= MATCH PARTIAL */
#line 333 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-1].minor.yy348 = FKEY_MATCH_PARTIAL; }
#line 2538 "parse.c"
        break;
      case 42: /* matcharg ::= MATCH FULL */
#line 334 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-1].minor.yy348 = FKEY_MATCH_FULL; }
#line 2543 "parse.c"
        break;
      case 43: /* matcharg ::= */
#line 335 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[1].minor.yy348 = FKEY_MATCH_SIMPLE; }
#line 2548 "parse.c"
        break;
      case 44: /* refact ::= SET NULL */
#line 338 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-1].minor.yy348 = FKEY_ACTION_SET_NULL; }
#line 2553 "parse.c"
        break;
      case 45: /* refact ::= SET DEFAULT */
#line 339 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-1].minor.yy348 = FKEY_ACTION_SET_DEFAULT; }
#line 2558 "parse.c"
        break;
      case 46: /* refact ::= CASCADE */
#line 340 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy348 = FKEY_ACTION_CASCADE; }
#line 2563 "parse.c"
        break;
      case 47: /* refact ::= RESTRICT */
#line 341 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy348 = FKEY_ACTION_RESTRICT; }
#line 2568 "parse.c"
        break;
      case 48: /* refact ::= NO ACTION */
#line 342 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-1].minor.yy348 = FKEY_NO_ACTION; }
#line 2573 "parse.c"
        break;
      case 49: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
#line 344 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-2].minor.yy348 = 0;}
#line 2578 "parse.c"
        break;
      case 50: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 61: /* orconf ::= OR resolvetype */ yytestcase(yyruleno==61);
      case 133: /* insert_cmd ::= INSERT orconf */ yytestcase(yyruleno==133);
#line 345 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-1].minor.yy348 = yymsp[0].minor.yy348;}
#line 2585 "parse.c"
        break;
      case 52: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
      case 66: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==66);
      case 186: /* between_op ::= NOT BETWEEN */ yytestcase(yyruleno==186);
      case 189: /* in_op ::= NOT IN */ yytestcase(yyruleno==189);
#line 348 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-1].minor.yy348 = 1;}
#line 2593 "parse.c"
        break;
      case 53: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
#line 349 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-1].minor.yy348 = 0;}
#line 2598 "parse.c"
        break;
      case 54: /* tcons ::= cconsname PRIMARY KEY LP sortlist autoinc RP */
#line 351 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  pParse->create_table_def.has_autoinc = yymsp[-1].minor.yy348;
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-6].minor.yy167, yymsp[-2].minor.yy402,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, SORT_ORDER_ASC, false);
  sqlAddPrimaryKey(pParse);
}
#line 2608 "parse.c"
        break;
      case 55: /* tcons ::= cconsname UNIQUE LP sortlist RP */
#line 357 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-4].minor.yy167, yymsp[-1].minor.yy402,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2618 "parse.c"
        break;
      case 56: /* tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 365 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-11].minor.yy167, yymsp[-7].minor.yy402, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy402, yymsp[-2].minor.yy348, yymsp[-1].minor.yy348, yymsp[0].minor.yy348);
  sql_create_foreign_key(pParse);
}
#line 2626 "parse.c"
        break;
      case 58: /* onconf ::= */
#line 380 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy348 = ON_CONFLICT_ACTION_ABORT;}
#line 2631 "parse.c"
        break;
      case 59: /* onconf ::= ON CONFLICT resolvetype */
#line 381 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-2].minor.yy348 = yymsp[0].minor.yy348;}
#line 2636 "parse.c"
        break;
      case 60: /* orconf ::= */
#line 382 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy348 = ON_CONFLICT_ACTION_DEFAULT;}
#line 2641 "parse.c"
        break;
      case 62: /* resolvetype ::= IGNORE */
#line 385 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = ON_CONFLICT_ACTION_IGNORE;}
#line 2646 "parse.c"
        break;
      case 63: /* resolvetype ::= REPLACE */
      case 134: /* insert_cmd ::= REPLACE */ yytestcase(yyruleno==134);
#line 386 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = ON_CONFLICT_ACTION_REPLACE;}
#line 2652 "parse.c"
        break;
      case 64: /* cmd ::= DROP TABLE ifexists fullname */
#line 391 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_table_def_init(&pParse->drop_table_def, yymsp[0].minor.yy3, &t, yymsp[-1].minor.yy348);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2662 "parse.c"
        break;
      case 65: /* cmd ::= DROP VIEW ifexists fullname */
#line 398 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_view_def_init(&pParse->drop_view_def, yymsp[0].minor.yy3, &t, yymsp[-1].minor.yy348);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2672 "parse.c"
        break;
      case 68: /* cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select */
#line 412 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  if (!pParse->parse_only) {
    create_view_def_init(&pParse->create_view_def, &yymsp[-3].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-2].minor.yy402, yymsp[0].minor.yy43, yymsp[-4].minor.yy348);
    pParse->initiateTTrans = true;
    sql_create_view(pParse);
  } else {
    sql_store_select(pParse, yymsp[0].minor.yy43);
  }
}
#line 2685 "parse.c"
        break;
      case 69: /* cmd ::= select */
#line 424 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0, 0, 0};
  if(!pParse->parse_only)
          sqlSelect(pParse, yymsp[0].minor.yy43, &dest);
  else
          sql_expr_extract_select(pParse, yymsp[0].minor.yy43);
  sql_select_delete(pParse->db, yymsp[0].minor.yy43);
}
#line 2697 "parse.c"
        break;
      case 70: /* select ::= with selectnowith */
#line 467 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  Select *p = yymsp[0].minor.yy43;
  if( p ){
    p->pWith = yymsp[-1].minor.yy4;
    parserDoubleLinkSelect(pParse, p);
  }else{
    sqlWithDelete(pParse->db, yymsp[-1].minor.yy4);
  }
  yymsp[-1].minor.yy43 = p; /*A-overwrites-W*/
}
#line 2711 "parse.c"
        break;
      case 71: /* selectnowith ::= selectnowith multiselect_op oneselect */
#line 480 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  Select *pRhs = yymsp[0].minor.yy43;
  Select *pLhs = yymsp[-2].minor.yy43;
  if( pRhs && pRhs->pPrior ){
    SrcList *pFrom;
    Token x;
    x.n = 0;
    parserDoubleLinkSelect(pParse, pRhs);
    pFrom = sqlSrcListAppendFromTerm(pParse,0,0,&x,pRhs,0,0);
    pRhs = sqlSelectNew(pParse,0,pFrom,0,0,0,0,0,0,0);
  }
  if( pRhs ){
    pRhs->op = (u8)yymsp[-1].minor.yy348;
    pRhs->pPrior = pLhs;
    if( ALWAYS(pLhs) ) pLhs->selFlags &= ~SF_MultiValue;
    pRhs->selFlags &= ~SF_MultiValue;
    if( yymsp[-1].minor.yy348!=TK_ALL ) pParse->hasCompound = 1;
  }else{
    sql_select_delete(pParse->db, pLhs);
  }
  yymsp[-2].minor.yy43 = pRhs;
}
#line 2737 "parse.c"
        break;
      case 72: /* multiselect_op ::= UNION */
      case 74: /* multiselect_op ::= EXCEPT|INTERSECT */ yytestcase(yyruleno==74);
#line 503 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = yymsp[0].major; /*A-overwrites-OP*/}
#line 2743 "parse.c"
        break;
      case 73: /* multiselect_op ::= UNION ALL */
#line 504 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-1].minor.yy348 = TK_ALL;}
#line 2748 "parse.c"
        break;
      case 75: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 508 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
#ifdef SQL_DEBUG
  Token s = yymsp[-8].minor.yy0; /*A-overwrites-S*/
#endif
  if (yymsp[0].minor.yy20.pLimit != NULL)
    sql_expr_check_sort_orders(pParse, yymsp[-1].minor.yy402);
  yymsp[-8].minor.yy43 = sqlSelectNew(pParse,yymsp[-6].minor.yy402,yymsp[-5].minor.yy3,yymsp[-4].minor.yy2,yymsp[-3].minor.yy402,yymsp[-2].minor.yy2,yymsp[-1].minor.yy402,yymsp[-7].minor.yy348,yymsp[0].minor.yy20.pLimit,yymsp[0].minor.yy20.pOffset);
#ifdef SQL_DEBUG
  /* Populate the Select.zSelName[] string that is used to help with
  ** query planner debugging, to differentiate between multiple Select
  ** objects in a complex query.
  **
  ** If the SELECT keyword is immediately followed by a C-style comment
  ** then extract the first few alphanumeric characters from within that
  ** comment to be the zSelName value.  Otherwise, the label is #N where
  ** is an integer that is incremented with each SELECT statement seen.
  */
  if( yymsp[-8].minor.yy43!=0 ){
    const char *z = s.z+6;
    int i;
    sql_snprintf(sizeof(yymsp[-8].minor.yy43->zSelName), yymsp[-8].minor.yy43->zSelName, "#%d",
                     ++pParse->nSelect);
    while( z[0]==' ' ) z++;
    if( z[0]=='/' && z[1]=='*' ){
      z += 2;
      while( z[0]==' ' ) z++;
      for(i=0; sqlIsalnum(z[i]); i++){}
      sql_snprintf(sizeof(yymsp[-8].minor.yy43->zSelName), yymsp[-8].minor.yy43->zSelName, "%.*s", i, z);
    }
  }
#endif /* SQL_DEBUG */
}
#line 2784 "parse.c"
        break;
      case 76: /* values ::= VALUES LP nexprlist RP */
#line 544 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy43 = sqlSelectNew(pParse,yymsp[-1].minor.yy402,0,0,0,0,0,SF_Values,0,0);
}
#line 2791 "parse.c"
        break;
      case 77: /* values ::= values COMMA LP exprlist RP */
#line 547 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  Select *pRight, *pLeft = yymsp[-4].minor.yy43;
  pRight = sqlSelectNew(pParse,yymsp[-1].minor.yy402,0,0,0,0,0,SF_Values|SF_MultiValue,0,0);
  if( ALWAYS(pLeft) ) pLeft->selFlags &= ~SF_MultiValue;
  if( pRight ){
    pRight->op = TK_ALL;
    pRight->pPrior = pLeft;
    yymsp[-4].minor.yy43 = pRight;
  }else{
    yymsp[-4].minor.yy43 = pLeft;
  }
}
#line 2807 "parse.c"
        break;
      case 78: /* distinct ::= DISTINCT */
#line 564 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = SF_Distinct;}
#line 2812 "parse.c"
        break;
      case 79: /* distinct ::= ALL */
#line 565 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = SF_All;}
#line 2817 "parse.c"
        break;
      case 81: /* sclp ::= */
      case 107: /* orderby_opt ::= */ yytestcase(yyruleno==107);
      case 114: /* groupby_opt ::= */ yytestcase(yyruleno==114);
      case 200: /* exprlist ::= */ yytestcase(yyruleno==200);
      case 203: /* paren_exprlist ::= */ yytestcase(yyruleno==203);
      case 208: /* eidlist_opt ::= */ yytestcase(yyruleno==208);
#line 578 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy402 = 0;}
#line 2827 "parse.c"
        break;
      case 82: /* selcollist ::= sclp expr as */
#line 579 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
   yymsp[-2].minor.yy402 = sql_expr_list_append(pParse->db, yymsp[-2].minor.yy402, yymsp[-1].minor.yy150.pExpr);
   if( yymsp[0].minor.yy0.n>0 ) sqlExprListSetName(pParse, yymsp[-2].minor.yy402, &yymsp[0].minor.yy0, 1);
   sqlExprListSetSpan(pParse,yymsp[-2].minor.yy402,&yymsp[-1].minor.yy150);
}
#line 2836 "parse.c"
        break;
      case 83: /* selcollist ::= sclp STAR */
#line 584 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_anon(pParse->db, TK_ASTERISK);
  if (p == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-1].minor.yy402 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy402, p);
}
#line 2848 "parse.c"
        break;
      case 84: /* selcollist ::= sclp nm DOT STAR */
#line 592 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  struct Expr *pLeft = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (pLeft == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Expr *pRight = sqlPExpr(pParse, TK_ASTERISK, 0, 0);
  Expr *pDot = sqlPExpr(pParse, TK_DOT, pLeft, pRight);
  yymsp[-3].minor.yy402 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy402, pDot);
}
#line 2862 "parse.c"
        break;
      case 85: /* as ::= AS nm */
      case 220: /* plus_num ::= PLUS INTEGER|FLOAT */ yytestcase(yyruleno==220);
      case 221: /* minus_num ::= MINUS INTEGER|FLOAT */ yytestcase(yyruleno==221);
#line 607 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-1].minor.yy0 = yymsp[0].minor.yy0;}
#line 2869 "parse.c"
        break;
      case 86: /* as ::= */
#line 609 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy0.n = 0; yymsp[1].minor.yy0.z = 0;}
#line 2874 "parse.c"
        break;
      case 87: /* from ::= */
#line 621 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy3 = sqlDbMallocZero(pParse->db, sizeof(*yymsp[1].minor.yy3));}
#line 2879 "parse.c"
        break;
      case 88: /* from ::= FROM seltablist */
#line 622 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy3 = yymsp[0].minor.yy3;
  sqlSrcListShiftJoinType(yymsp[-1].minor.yy3);
}
#line 2887 "parse.c"
        break;
      case 89: /* stl_prefix ::= seltablist joinop */
#line 630 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
   if( ALWAYS(yymsp[-1].minor.yy3 && yymsp[-1].minor.yy3->nSrc>0) ) yymsp[-1].minor.yy3->a[yymsp[-1].minor.yy3->nSrc-1].fg.jointype = (u8)yymsp[0].minor.yy348;
}
#line 2894 "parse.c"
        break;
      case 90: /* stl_prefix ::= */
#line 633 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy3 = 0;}
#line 2899 "parse.c"
        break;
      case 91: /* seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt */
#line 635 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy3 = sqlSrcListAppendFromTerm(pParse,yymsp[-5].minor.yy3,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy2,yymsp[0].minor.yy272);
  sqlSrcListIndexedBy(pParse, yymsp[-5].minor.yy3, &yymsp[-2].minor.yy0);
}
#line 2907 "parse.c"
        break;
      case 92: /* seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt */
#line 640 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy3 = sqlSrcListAppendFromTerm(pParse,yymsp[-7].minor.yy3,&yymsp[-6].minor.yy0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy2,yymsp[0].minor.yy272);
  sqlSrcListFuncArgs(pParse, yymsp[-7].minor.yy3, yymsp[-4].minor.yy402);
}
#line 2915 "parse.c"
        break;
      case 93: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 645 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy3 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy3,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy43,yymsp[-1].minor.yy2,yymsp[0].minor.yy272);
}
#line 2922 "parse.c"
        break;
      case 94: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 649 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  if( yymsp[-6].minor.yy3==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy2==0 && yymsp[0].minor.yy272==0 ){
    yymsp[-6].minor.yy3 = yymsp[-4].minor.yy3;
  }else if( yymsp[-4].minor.yy3->nSrc==1 ){
    yymsp[-6].minor.yy3 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy3,0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy2,yymsp[0].minor.yy272);
    if( yymsp[-6].minor.yy3 ){
      struct SrcList_item *pNew = &yymsp[-6].minor.yy3->a[yymsp[-6].minor.yy3->nSrc-1];
      struct SrcList_item *pOld = yymsp[-4].minor.yy3->a;
      pNew->zName = pOld->zName;
      pNew->pSelect = pOld->pSelect;
      pOld->zName =  0;
      pOld->pSelect = 0;
    }
    sqlSrcListDelete(pParse->db, yymsp[-4].minor.yy3);
  }else{
    Select *pSubquery;
    sqlSrcListShiftJoinType(yymsp[-4].minor.yy3);
    pSubquery = sqlSelectNew(pParse,0,yymsp[-4].minor.yy3,0,0,0,0,SF_NestedFrom,0,0);
    yymsp[-6].minor.yy3 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy3,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy2,yymsp[0].minor.yy272);
  }
}
#line 2947 "parse.c"
        break;
      case 95: /* fullname ::= nm */
#line 673 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  /* yylhsminor.yy3-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy3 = sql_src_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy3 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 2959 "parse.c"
  yymsp[0].minor.yy3 = yylhsminor.yy3;
        break;
      case 96: /* joinop ::= COMMA|JOIN */
#line 686 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy348 = JT_INNER; }
#line 2965 "parse.c"
        break;
      case 97: /* joinop ::= JOIN_KW JOIN */
#line 688 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-1].minor.yy348 = sqlJoinType(pParse,&yymsp[-1].minor.yy0,0,0);  /*X-overwrites-A*/}
#line 2970 "parse.c"
        break;
      case 98: /* joinop ::= JOIN_KW join_nm JOIN */
#line 690 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-2].minor.yy348 = sqlJoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); /*X-overwrites-A*/}
#line 2975 "parse.c"
        break;
      case 99: /* joinop ::= JOIN_KW join_nm join_nm JOIN */
#line 692 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-3].minor.yy348 = sqlJoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0);/*X-overwrites-A*/}
#line 2980 "parse.c"
        break;
      case 100: /* on_opt ::= ON expr */
      case 117: /* having_opt ::= HAVING expr */ yytestcase(yyruleno==117);
      case 125: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==125);
      case 198: /* case_else ::= ELSE expr */ yytestcase(yyruleno==198);
#line 696 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-1].minor.yy2 = yymsp[0].minor.yy150.pExpr;}
#line 2988 "parse.c"
        break;
      case 101: /* on_opt ::= */
      case 116: /* having_opt ::= */ yytestcase(yyruleno==116);
      case 124: /* where_opt ::= */ yytestcase(yyruleno==124);
      case 199: /* case_else ::= */ yytestcase(yyruleno==199);
#line 697 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy2 = 0;}
#line 2996 "parse.c"
        break;
      case 102: /* indexed_opt ::= */
#line 710 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy0.z=0; yymsp[1].minor.yy0.n=0;}
#line 3001 "parse.c"
        break;
      case 103: /* indexed_opt ::= INDEXED BY nm */
#line 711 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;}
#line 3006 "parse.c"
        break;
      case 104: /* indexed_opt ::= NOT INDEXED */
#line 712 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-1].minor.yy0.z=0; yymsp[-1].minor.yy0.n=1;}
#line 3011 "parse.c"
        break;
      case 105: /* using_opt ::= USING LP idlist RP */
#line 716 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-3].minor.yy272 = yymsp[-1].minor.yy272;}
#line 3016 "parse.c"
        break;
      case 106: /* using_opt ::= */
      case 135: /* idlist_opt ::= */ yytestcase(yyruleno==135);
#line 717 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy272 = 0;}
#line 3022 "parse.c"
        break;
      case 108: /* orderby_opt ::= ORDER BY sortlist */
      case 115: /* groupby_opt ::= GROUP BY nexprlist */ yytestcase(yyruleno==115);
#line 731 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-2].minor.yy402 = yymsp[0].minor.yy402;}
#line 3028 "parse.c"
        break;
      case 109: /* sortlist ::= sortlist COMMA expr sortorder */
#line 732 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy402 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy402,yymsp[-1].minor.yy150.pExpr);
  sqlExprListSetSortOrder(yymsp[-3].minor.yy402,yymsp[0].minor.yy348);
}
#line 3036 "parse.c"
        break;
      case 110: /* sortlist ::= expr sortorder */
#line 736 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  /* yylhsminor.yy402-overwrites-yymsp[-1].minor.yy150. */
  yylhsminor.yy402 = sql_expr_list_append(pParse->db,NULL,yymsp[-1].minor.yy150.pExpr);
  sqlExprListSetSortOrder(yylhsminor.yy402,yymsp[0].minor.yy348);
}
#line 3045 "parse.c"
  yymsp[-1].minor.yy402 = yylhsminor.yy402;
        break;
      case 111: /* sortorder ::= ASC */
#line 744 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = SORT_ORDER_ASC;}
#line 3051 "parse.c"
        break;
      case 112: /* sortorder ::= DESC */
#line 745 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = SORT_ORDER_DESC;}
#line 3056 "parse.c"
        break;
      case 113: /* sortorder ::= */
#line 746 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy348 = SORT_ORDER_UNDEF;}
#line 3061 "parse.c"
        break;
      case 118: /* limit_opt ::= */
#line 771 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy20.pLimit = 0; yymsp[1].minor.yy20.pOffset = 0;}
#line 3066 "parse.c"
        break;
      case 119: /* limit_opt ::= LIMIT expr */
#line 772 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-1].minor.yy20.pLimit = yymsp[0].minor.yy150.pExpr; yymsp[-1].minor.yy20.pOffset = 0;}
#line 3071 "parse.c"
        break;
      case 120: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 774 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-3].minor.yy20.pLimit = yymsp[-2].minor.yy150.pExpr; yymsp[-3].minor.yy20.pOffset = yymsp[0].minor.yy150.pExpr;}
#line 3076 "parse.c"
        break;
      case 121: /* limit_opt ::= LIMIT expr COMMA expr */
#line 776 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-3].minor.yy20.pOffset = yymsp[-2].minor.yy150.pExpr; yymsp[-3].minor.yy20.pLimit = yymsp[0].minor.yy150.pExpr;}
#line 3081 "parse.c"
        break;
      case 122: /* cmd ::= with DELETE FROM fullname indexed_opt where_opt */
#line 780 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy4, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-2].minor.yy3, &yymsp[-1].minor.yy0);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sql_table_delete_from(pParse,yymsp[-2].minor.yy3,yymsp[0].minor.yy2);
}
#line 3093 "parse.c"
        break;
      case 123: /* cmd ::= TRUNCATE TABLE fullname */
#line 791 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  pParse->initiateTTrans = true;
  sql_table_truncate(pParse, yymsp[0].minor.yy3);
}
#line 3101 "parse.c"
        break;
      case 126: /* cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt */
#line 805 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-7].minor.yy4, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-4].minor.yy3, &yymsp[-3].minor.yy0);
  if (yymsp[-1].minor.yy402 != NULL && yymsp[-1].minor.yy402->nExpr > pParse->db->aLimit[SQL_LIMIT_COLUMN]) {
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of columns in set "\
             "list", yymsp[-1].minor.yy402->nExpr, pParse->db->aLimit[SQL_LIMIT_COLUMN]);
    pParse->is_aborted = true;
  }
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlUpdate(pParse,yymsp[-4].minor.yy3,yymsp[-1].minor.yy402,yymsp[0].minor.yy2,yymsp[-5].minor.yy348);
}
#line 3118 "parse.c"
        break;
      case 127: /* setlist ::= setlist COMMA nm EQ expr */
#line 822 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy402 = sql_expr_list_append(pParse->db, yymsp[-4].minor.yy402, yymsp[0].minor.yy150.pExpr);
  sqlExprListSetName(pParse, yymsp[-4].minor.yy402, &yymsp[-2].minor.yy0, 1);
}
#line 3126 "parse.c"
        break;
      case 128: /* setlist ::= setlist COMMA LP idlist RP EQ expr */
#line 826 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy402 = sqlExprListAppendVector(pParse, yymsp[-6].minor.yy402, yymsp[-3].minor.yy272, yymsp[0].minor.yy150.pExpr);
}
#line 3133 "parse.c"
        break;
      case 129: /* setlist ::= nm EQ expr */
#line 829 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yylhsminor.yy402 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy150.pExpr);
  sqlExprListSetName(pParse, yylhsminor.yy402, &yymsp[-2].minor.yy0, 1);
}
#line 3141 "parse.c"
  yymsp[-2].minor.yy402 = yylhsminor.yy402;
        break;
      case 130: /* setlist ::= LP idlist RP EQ expr */
#line 833 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy402 = sqlExprListAppendVector(pParse, 0, yymsp[-3].minor.yy272, yymsp[0].minor.yy150.pExpr);
}
#line 3149 "parse.c"
        break;
      case 131: /* cmd ::= with insert_cmd INTO fullname idlist_opt select */
#line 839 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy4, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-2].minor.yy3, yymsp[0].minor.yy43, yymsp[-1].minor.yy272, yymsp[-4].minor.yy348);
}
#line 3160 "parse.c"
        break;
      case 132: /* cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES */
#line 847 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-6].minor.yy4, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-3].minor.yy3, 0, yymsp[-2].minor.yy272, yymsp[-5].minor.yy348);
}
#line 3171 "parse.c"
        break;
      case 136: /* idlist_opt ::= LP idlist RP */
#line 865 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-2].minor.yy272 = yymsp[-1].minor.yy272;}
#line 3176 "parse.c"
        break;
      case 137: /* idlist ::= idlist COMMA nm */
#line 866 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy272 = sql_id_list_append(pParse->db,yymsp[-2].minor.yy272,&yymsp[0].minor.yy0);
  if (yymsp[-2].minor.yy272 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3187 "parse.c"
        break;
      case 138: /* idlist ::= nm */
#line 873 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  /* yylhsminor.yy272-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy272 = sql_id_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy272 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3199 "parse.c"
  yymsp[0].minor.yy272 = yylhsminor.yy272;
        break;
      case 139: /* expr ::= LP expr RP */
#line 976 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{spanSet(&yymsp[-2].minor.yy150,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/  yymsp[-2].minor.yy150.pExpr = yymsp[-1].minor.yy150.pExpr;}
#line 3205 "parse.c"
        break;
      case 140: /* term ::= NULL */
      case 144: /* term ::= FLOAT|BLOB */ yytestcase(yyruleno==144);
      case 145: /* term ::= STRING */ yytestcase(yyruleno==145);
      case 146: /* term ::= FALSE */ yytestcase(yyruleno==146);
      case 147: /* term ::= TRUE */ yytestcase(yyruleno==147);
      case 148: /* term ::= UNKNOWN */ yytestcase(yyruleno==148);
#line 977 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy150,pParse,yymsp[0].major,yymsp[0].minor.yy0);/*A-overwrites-X*/}
#line 3215 "parse.c"
        break;
      case 141: /* expr ::= ID|INDEXED */
      case 142: /* expr ::= JOIN_KW */ yytestcase(yyruleno==142);
#line 978 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy150,pParse,TK_ID,yymsp[0].minor.yy0); /*A-overwrites-X*/}
#line 3221 "parse.c"
        break;
      case 143: /* expr ::= nm DOT nm */
#line 980 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  struct Expr *temp1 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (temp1 == NULL) {
    pParse->is_aborted = true;
    return;
  }
  struct Expr *temp2 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[0].minor.yy0);
  if (temp2 == NULL) {
    sql_expr_delete(pParse->db, temp1, false);
    pParse->is_aborted = true;
    return;
  }
  spanSet(&yymsp[-2].minor.yy150,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-2].minor.yy150.pExpr = sqlPExpr(pParse, TK_DOT, temp1, temp2);
}
#line 3240 "parse.c"
        break;
      case 149: /* term ::= INTEGER */
#line 1001 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yylhsminor.yy150.pExpr = sql_expr_new_dequoted(pParse->db, TK_INTEGER, &yymsp[0].minor.yy0);
  if (yylhsminor.yy150.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yylhsminor.yy150.pExpr->type = FIELD_TYPE_INTEGER;
  yylhsminor.yy150.zStart = yymsp[0].minor.yy0.z;
  yylhsminor.yy150.zEnd = yymsp[0].minor.yy0.z + yymsp[0].minor.yy0.n;
  if( yylhsminor.yy150.pExpr ) yylhsminor.yy150.pExpr->flags |= EP_Leaf;
}
#line 3255 "parse.c"
  yymsp[0].minor.yy150 = yylhsminor.yy150;
        break;
      case 150: /* expr ::= VARIABLE */
#line 1012 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  Token t = yymsp[0].minor.yy0;
  if (pParse->parse_only) {
    spanSet(&yylhsminor.yy150, &t, &t);
    diag_set(ClientError, ER_SQL_PARSER_GENERIC,
             "bindings are not allowed in DDL");
    pParse->is_aborted = true;
    yylhsminor.yy150.pExpr = NULL;
  } else if (!(yymsp[0].minor.yy0.z[0]=='#' && sqlIsdigit(yymsp[0].minor.yy0.z[1]))) {
    u32 n = yymsp[0].minor.yy0.n;
    spanExpr(&yylhsminor.yy150, pParse, TK_VARIABLE, yymsp[0].minor.yy0);
    if (yylhsminor.yy150.pExpr->u.zToken[0] == '?' && n > 1) {
      diag_set(ClientError, ER_SQL_UNRECOGNIZED_SYNTAX, t.n, t.z);
      pParse->is_aborted = true;
    } else {
      sqlExprAssignVarNumber(pParse, yylhsminor.yy150.pExpr, n);
    }
  }else{
    assert( t.n>=2 );
    spanSet(&yylhsminor.yy150, &t, &t);
    diag_set(ClientError, ER_SQL_UNRECOGNIZED_SYNTAX, t.n, t.z);
    pParse->is_aborted = true;
    yylhsminor.yy150.pExpr = NULL;
  }
}
#line 3285 "parse.c"
  yymsp[0].minor.yy150 = yylhsminor.yy150;
        break;
      case 151: /* expr ::= expr COLLATE ID|INDEXED */
#line 1037 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy150.pExpr = sqlExprAddCollateToken(pParse, yymsp[-2].minor.yy150.pExpr, &yymsp[0].minor.yy0, 1);
  yymsp[-2].minor.yy150.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3294 "parse.c"
        break;
      case 152: /* expr ::= CAST LP expr AS typedef RP */
#line 1042 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy150,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-5].minor.yy150.pExpr = sql_expr_new_dequoted(pParse->db, TK_CAST, NULL);
  if (yymsp[-5].minor.yy150.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy150.pExpr->type = yymsp[-1].minor.yy434.type;
  sqlExprAttachSubtrees(pParse->db, yymsp[-5].minor.yy150.pExpr, yymsp[-3].minor.yy150.pExpr, 0);
}
#line 3308 "parse.c"
        break;
      case 153: /* expr ::= TRIM LP trim_operands RP */
#line 1053 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yylhsminor.yy150.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy215, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy150, &yymsp[-3].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3316 "parse.c"
  yymsp[-3].minor.yy150 = yylhsminor.yy150;
        break;
      case 154: /* trim_operands ::= trim_from_clause expr */
#line 1061 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yylhsminor.yy215 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy215, yymsp[0].minor.yy150.pExpr);
}
#line 3324 "parse.c"
  yymsp[-1].minor.yy215 = yylhsminor.yy215;
        break;
      case 155: /* trim_operands ::= expr */
#line 1065 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yylhsminor.yy215 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy150.pExpr);
}
#line 3332 "parse.c"
  yymsp[0].minor.yy215 = yylhsminor.yy215;
        break;
      case 156: /* trim_from_clause ::= expr FROM */
#line 1077 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yylhsminor.yy215 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy150.pExpr);
}
#line 3340 "parse.c"
  yymsp[-1].minor.yy215 = yylhsminor.yy215;
        break;
      case 157: /* trim_from_clause ::= trim_specification expr_optional FROM */
#line 1081 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[yymsp[-2].minor.yy429]);
  yylhsminor.yy215 = sql_expr_list_append(pParse->db, NULL, p);
  if (yymsp[-1].minor.yy87 != NULL)
    yylhsminor.yy215 = sql_expr_list_append(pParse->db, yylhsminor.yy215, yymsp[-1].minor.yy87);
}
#line 3352 "parse.c"
  yymsp[-2].minor.yy215 = yylhsminor.yy215;
        break;
      case 158: /* expr_optional ::= */
#line 1092 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[1].minor.yy87 = NULL; }
#line 3358 "parse.c"
        break;
      case 159: /* expr_optional ::= expr */
#line 1093 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yylhsminor.yy87 = yymsp[0].minor.yy150.pExpr; }
#line 3363 "parse.c"
  yymsp[0].minor.yy87 = yylhsminor.yy87;
        break;
      case 160: /* trim_specification ::= LEADING */
#line 1097 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy429 = TRIM_LEADING; }
#line 3369 "parse.c"
        break;
      case 161: /* trim_specification ::= TRAILING */
#line 1098 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy429 = TRIM_TRAILING; }
#line 3374 "parse.c"
        break;
      case 162: /* trim_specification ::= BOTH */
#line 1099 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy429 = TRIM_BOTH; }
#line 3379 "parse.c"
        break;
      case 163: /* expr ::= ID|INDEXED LP distinct exprlist RP */
      case 164: /* expr ::= type_func LP distinct exprlist RP */ yytestcase(yyruleno==164);
#line 1101 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy402 && yymsp[-1].minor.yy402->nExpr>pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG] ){
    const char *err =
      tt_sprintf("Number of arguments to function %.*s", yymsp[-4].minor.yy0.n, yymsp[-4].minor.yy0.z);
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, err, yymsp[-1].minor.yy402->nExpr,
             pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG]);
    pParse->is_aborted = true;
  }
  yylhsminor.yy150.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy402, &yymsp[-4].minor.yy0);
  spanSet(&yylhsminor.yy150,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy348==SF_Distinct && yylhsminor.yy150.pExpr ){
    yylhsminor.yy150.pExpr->flags |= EP_Distinct;
  }
}
#line 3398 "parse.c"
  yymsp[-4].minor.yy150 = yylhsminor.yy150;
        break;
      case 165: /* expr ::= ID|INDEXED LP STAR RP */
#line 1136 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yylhsminor.yy150.pExpr = sqlExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy150,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 3407 "parse.c"
  yymsp[-3].minor.yy150 = yylhsminor.yy150;
        break;
      case 166: /* expr ::= LP nexprlist COMMA expr RP */
#line 1171 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy402, yymsp[-1].minor.yy150.pExpr);
  yylhsminor.yy150.pExpr = sqlPExpr(pParse, TK_VECTOR, 0, 0);
  if( yylhsminor.yy150.pExpr ){
    yylhsminor.yy150.pExpr->x.pList = pList;
    spanSet(&yylhsminor.yy150, &yymsp[-4].minor.yy0, &yymsp[0].minor.yy0);
  }else{
    sql_expr_list_delete(pParse->db, pList);
  }
}
#line 3422 "parse.c"
  yymsp[-4].minor.yy150 = yylhsminor.yy150;
        break;
      case 167: /* expr ::= expr AND expr */
      case 168: /* expr ::= expr OR expr */ yytestcase(yyruleno==168);
      case 169: /* expr ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==169);
      case 170: /* expr ::= expr EQ|NE expr */ yytestcase(yyruleno==170);
      case 171: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==171);
      case 172: /* expr ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==172);
      case 173: /* expr ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==173);
      case 174: /* expr ::= expr CONCAT expr */ yytestcase(yyruleno==174);
#line 1182 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{spanBinaryExpr(pParse,yymsp[-1].major,&yymsp[-2].minor.yy150,&yymsp[0].minor.yy150);}
#line 3435 "parse.c"
        break;
      case 175: /* likeop ::= LIKE_KW|MATCH */
#line 1195 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy0=yymsp[0].minor.yy0;/*A-overwrites-X*/}
#line 3440 "parse.c"
        break;
      case 176: /* likeop ::= NOT LIKE_KW|MATCH */
#line 1196 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-1].minor.yy0=yymsp[0].minor.yy0; yymsp[-1].minor.yy0.n|=0x80000000; /*yymsp[-1].minor.yy0-overwrite-yymsp[0].minor.yy0*/}
#line 3445 "parse.c"
        break;
      case 177: /* expr ::= expr likeop expr */
#line 1197 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-1].minor.yy0.n & 0x80000000;
  yymsp[-1].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[0].minor.yy150.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-2].minor.yy150.pExpr);
  yymsp[-2].minor.yy150.pExpr = sqlExprFunction(pParse, pList, &yymsp[-1].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-2].minor.yy150);
  yymsp[-2].minor.yy150.zEnd = yymsp[0].minor.yy150.zEnd;
  if( yymsp[-2].minor.yy150.pExpr ) yymsp[-2].minor.yy150.pExpr->flags |= EP_InfixFunc;
}
#line 3460 "parse.c"
        break;
      case 178: /* expr ::= expr likeop expr ESCAPE expr */
#line 1208 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-3].minor.yy0.n & 0x80000000;
  yymsp[-3].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy150.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-4].minor.yy150.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy150.pExpr);
  yymsp[-4].minor.yy150.pExpr = sqlExprFunction(pParse, pList, &yymsp[-3].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-4].minor.yy150);
  yymsp[-4].minor.yy150.zEnd = yymsp[0].minor.yy150.zEnd;
  if( yymsp[-4].minor.yy150.pExpr ) yymsp[-4].minor.yy150.pExpr->flags |= EP_InfixFunc;
}
#line 3476 "parse.c"
        break;
      case 179: /* expr ::= expr IS NULL */
#line 1238 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_ISNULL,&yymsp[-2].minor.yy150,&yymsp[0].minor.yy0);}
#line 3481 "parse.c"
        break;
      case 180: /* expr ::= expr IS NOT NULL */
#line 1239 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_NOTNULL,&yymsp[-3].minor.yy150,&yymsp[0].minor.yy0);}
#line 3486 "parse.c"
        break;
      case 181: /* expr ::= NOT expr */
      case 182: /* expr ::= BITNOT expr */ yytestcase(yyruleno==182);
#line 1261 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy150,pParse,yymsp[-1].major,&yymsp[0].minor.yy150,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3492 "parse.c"
        break;
      case 183: /* expr ::= MINUS expr */
#line 1265 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy150,pParse,TK_UMINUS,&yymsp[0].minor.yy150,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3497 "parse.c"
        break;
      case 184: /* expr ::= PLUS expr */
#line 1267 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy150,pParse,TK_UPLUS,&yymsp[0].minor.yy150,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3502 "parse.c"
        break;
      case 185: /* between_op ::= BETWEEN */
      case 188: /* in_op ::= IN */ yytestcase(yyruleno==188);
#line 1270 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = 0;}
#line 3508 "parse.c"
        break;
      case 187: /* expr ::= expr between_op expr AND expr */
#line 1272 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy150.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy150.pExpr);
  yymsp[-4].minor.yy150.pExpr = sqlPExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy150.pExpr, 0);
  if( yymsp[-4].minor.yy150.pExpr ){
    yymsp[-4].minor.yy150.pExpr->x.pList = pList;
  }else{
    sql_expr_list_delete(pParse->db, pList);
  } 
  exprNot(pParse, yymsp[-3].minor.yy348, &yymsp[-4].minor.yy150);
  yymsp[-4].minor.yy150.zEnd = yymsp[0].minor.yy150.zEnd;
}
#line 3524 "parse.c"
        break;
      case 190: /* expr ::= expr in_op LP exprlist RP */
#line 1287 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy402==0 ){
    /* Expressions of the form
    **
    **      expr1 IN ()
    **      expr1 NOT IN ()
    **
    ** simplify to constants 0 (false) and 1 (true), respectively,
    ** regardless of the value of expr1.
    */
    sql_expr_delete(pParse->db, yymsp[-4].minor.yy150.pExpr, false);
    int tk = yymsp[-3].minor.yy348 == 0 ? TK_FALSE : TK_TRUE;
    yymsp[-4].minor.yy150.pExpr = sql_expr_new_anon(pParse->db, tk);
    if (yymsp[-4].minor.yy150.pExpr == NULL) {
      pParse->is_aborted = true;
      return;
    }
    yymsp[-4].minor.yy150.pExpr->type = FIELD_TYPE_BOOLEAN;
  }else if( yymsp[-1].minor.yy402->nExpr==1 ){
    /* Expressions of the form:
    **
    **      expr1 IN (?1)
    **      expr1 NOT IN (?2)
    **
    ** with exactly one value on the RHS can be simplified to something
    ** like this:
    **
    **      expr1 == ?1
    **      expr1 <> ?2
    */
    Expr *pRHS = yymsp[-1].minor.yy402->a[0].pExpr;
    yymsp[-1].minor.yy402->a[0].pExpr = 0;
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy402);
    yymsp[-4].minor.yy150.pExpr = sqlPExpr(pParse, yymsp[-3].minor.yy348 ? TK_NE : TK_EQ, yymsp[-4].minor.yy150.pExpr, pRHS);
  }else{
    yymsp[-4].minor.yy150.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy150.pExpr, 0);
    if( yymsp[-4].minor.yy150.pExpr ){
      yymsp[-4].minor.yy150.pExpr->x.pList = yymsp[-1].minor.yy402;
      sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy150.pExpr);
    }else{
      sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy402);
    }
    exprNot(pParse, yymsp[-3].minor.yy348, &yymsp[-4].minor.yy150);
  }
  yymsp[-4].minor.yy150.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3574 "parse.c"
        break;
      case 191: /* expr ::= LP select RP */
#line 1333 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  spanSet(&yymsp[-2].minor.yy150,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  yymsp[-2].minor.yy150.pExpr = sqlPExpr(pParse, TK_SELECT, 0, 0);
  sqlPExprAddSelect(pParse, yymsp[-2].minor.yy150.pExpr, yymsp[-1].minor.yy43);
}
#line 3583 "parse.c"
        break;
      case 192: /* expr ::= expr in_op LP select RP */
#line 1338 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy150.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy150.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-4].minor.yy150.pExpr, yymsp[-1].minor.yy43);
  exprNot(pParse, yymsp[-3].minor.yy348, &yymsp[-4].minor.yy150);
  yymsp[-4].minor.yy150.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3593 "parse.c"
        break;
      case 193: /* expr ::= expr in_op nm paren_exprlist */
#line 1344 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  struct SrcList *pSrc = sql_src_list_append(pParse->db, 0,&yymsp[-1].minor.yy0);
  if (pSrc == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Select *pSelect = sqlSelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
  if( yymsp[0].minor.yy402 )  sqlSrcListFuncArgs(pParse, pSelect ? pSrc : 0, yymsp[0].minor.yy402);
  yymsp[-3].minor.yy150.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-3].minor.yy150.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-3].minor.yy150.pExpr, pSelect);
  exprNot(pParse, yymsp[-2].minor.yy348, &yymsp[-3].minor.yy150);
  yymsp[-3].minor.yy150.zEnd = &yymsp[-1].minor.yy0.z[yymsp[-1].minor.yy0.n];
}
#line 3610 "parse.c"
        break;
      case 194: /* expr ::= EXISTS LP select RP */
#line 1357 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  Expr *p;
  spanSet(&yymsp[-3].minor.yy150,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  p = yymsp[-3].minor.yy150.pExpr = sqlPExpr(pParse, TK_EXISTS, 0, 0);
  sqlPExprAddSelect(pParse, p, yymsp[-1].minor.yy43);
}
#line 3620 "parse.c"
        break;
      case 195: /* expr ::= CASE expr_optional case_exprlist case_else END */
#line 1365 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  spanSet(&yymsp[-4].minor.yy150,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-C*/
  yymsp[-4].minor.yy150.pExpr = sqlPExpr(pParse, TK_CASE, yymsp[-3].minor.yy87, 0);
  if( yymsp[-4].minor.yy150.pExpr ){
    yymsp[-4].minor.yy150.pExpr->x.pList = yymsp[-1].minor.yy2 ? sql_expr_list_append(pParse->db,yymsp[-2].minor.yy402,yymsp[-1].minor.yy2) : yymsp[-2].minor.yy402;
    sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy150.pExpr);
  }else{
    sql_expr_list_delete(pParse->db, yymsp[-2].minor.yy402);
    sql_expr_delete(pParse->db, yymsp[-1].minor.yy2, false);
  }
}
#line 3635 "parse.c"
        break;
      case 196: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 1378 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy402 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy402, yymsp[-2].minor.yy150.pExpr);
  yymsp[-4].minor.yy402 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy402, yymsp[0].minor.yy150.pExpr);
}
#line 3643 "parse.c"
        break;
      case 197: /* case_exprlist ::= WHEN expr THEN expr */
#line 1382 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy402 = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy150.pExpr);
  yymsp[-3].minor.yy402 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy402, yymsp[0].minor.yy150.pExpr);
}
#line 3651 "parse.c"
        break;
      case 201: /* nexprlist ::= nexprlist COMMA expr */
#line 1399 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-2].minor.yy402 = sql_expr_list_append(pParse->db,yymsp[-2].minor.yy402,yymsp[0].minor.yy150.pExpr);}
#line 3656 "parse.c"
        break;
      case 202: /* nexprlist ::= expr */
#line 1401 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy402 = sql_expr_list_append(pParse->db,NULL,yymsp[0].minor.yy150.pExpr); /*A-overwrites-Y*/}
#line 3661 "parse.c"
        break;
      case 204: /* paren_exprlist ::= LP exprlist RP */
      case 209: /* eidlist_opt ::= LP eidlist RP */ yytestcase(yyruleno==209);
#line 1408 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-2].minor.yy402 = yymsp[-1].minor.yy402;}
#line 3667 "parse.c"
        break;
      case 205: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP */
#line 1414 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  struct SrcList *src_list = sql_src_list_append(pParse->db,0,&yymsp[-3].minor.yy0);
  if (src_list == NULL) {
    pParse->is_aborted = true;
    return;
  }
  create_index_def_init(&pParse->create_index_def, src_list, &yymsp[-5].minor.yy0, yymsp[-1].minor.yy402, yymsp[-8].minor.yy348,
                        SORT_ORDER_ASC, yymsp[-6].minor.yy348);
  pParse->initiateTTrans = true;
  sql_create_index(pParse);
}
#line 3682 "parse.c"
        break;
      case 206: /* uniqueflag ::= UNIQUE */
#line 1427 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = SQL_INDEX_TYPE_UNIQUE;}
#line 3687 "parse.c"
        break;
      case 207: /* uniqueflag ::= */
#line 1428 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy348 = SQL_INDEX_TYPE_NON_UNIQUE;}
#line 3692 "parse.c"
        break;
      case 210: /* eidlist ::= eidlist COMMA nm */
#line 1463 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy402 = parserAddExprIdListTerm(pParse, yymsp[-2].minor.yy402, &yymsp[0].minor.yy0);
}
#line 3699 "parse.c"
        break;
      case 211: /* eidlist ::= nm */
#line 1466 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[0].minor.yy402 = parserAddExprIdListTerm(pParse, 0, &yymsp[0].minor.yy0); /*A-overwrites-Y*/
}
#line 3706 "parse.c"
        break;
      case 212: /* cmd ::= DROP INDEX ifexists nm ON fullname */
#line 1473 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  drop_index_def_init(&pParse->drop_index_def, yymsp[0].minor.yy3, &yymsp[-2].minor.yy0, yymsp[-3].minor.yy348);
  pParse->initiateTTrans = true;
  sql_drop_index(pParse);
}
#line 3715 "parse.c"
        break;
      case 213: /* cmd ::= PRAGMA nm */
#line 1481 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[0].minor.yy0,0,0,0);
}
#line 3722 "parse.c"
        break;
      case 214: /* cmd ::= PRAGMA nm EQ nmnum */
#line 1484 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0,0,0);
}
#line 3729 "parse.c"
        break;
      case 215: /* cmd ::= PRAGMA nm LP nmnum RP */
#line 1487 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0,0);
}
#line 3736 "parse.c"
        break;
      case 216: /* cmd ::= PRAGMA nm EQ minus_num */
#line 1490 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0,0,1);
}
#line 3743 "parse.c"
        break;
      case 217: /* cmd ::= PRAGMA nm LP minus_num RP */
#line 1493 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0,1);
}
#line 3750 "parse.c"
        break;
      case 218: /* cmd ::= PRAGMA nm LP nm DOT nm RP */
#line 1496 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-5].minor.yy0,&yymsp[-1].minor.yy0,&yymsp[-3].minor.yy0,0);
}
#line 3757 "parse.c"
        break;
      case 219: /* cmd ::= PRAGMA */
#line 1499 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
    sqlPragma(pParse, 0,0,0,0);
}
#line 3764 "parse.c"
        break;
      case 222: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1518 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  pParse->initiateTTrans = true;
  sql_trigger_finish(pParse, yymsp[-1].minor.yy347, &all);
}
#line 3775 "parse.c"
        break;
      case 223: /* trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1528 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  create_trigger_def_init(&pParse->create_trigger_def, yymsp[-2].minor.yy3, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy348, yymsp[-4].minor.yy338.a, yymsp[-4].minor.yy338.b, yymsp[0].minor.yy2,
                          yymsp[-7].minor.yy348);
  sql_trigger_begin(pParse);
  yymsp[-8].minor.yy0 = yymsp[-6].minor.yy0; /*yymsp[-8].minor.yy0-overwrites-T*/
}
#line 3785 "parse.c"
        break;
      case 224: /* trigger_time ::= BEFORE */
#line 1536 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy348 = TK_BEFORE; }
#line 3790 "parse.c"
        break;
      case 225: /* trigger_time ::= AFTER */
#line 1537 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy348 = TK_AFTER;  }
#line 3795 "parse.c"
        break;
      case 226: /* trigger_time ::= INSTEAD OF */
#line 1538 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-1].minor.yy348 = TK_INSTEAD;}
#line 3800 "parse.c"
        break;
      case 227: /* trigger_time ::= */
#line 1539 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[1].minor.yy348 = TK_BEFORE; }
#line 3805 "parse.c"
        break;
      case 228: /* trigger_event ::= DELETE|INSERT */
      case 229: /* trigger_event ::= UPDATE */ yytestcase(yyruleno==229);
#line 1543 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy338.a = yymsp[0].major; /*A-overwrites-X*/ yymsp[0].minor.yy338.b = 0;}
#line 3811 "parse.c"
        break;
      case 230: /* trigger_event ::= UPDATE OF idlist */
#line 1545 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[-2].minor.yy338.a = TK_UPDATE; yymsp[-2].minor.yy338.b = yymsp[0].minor.yy272;}
#line 3816 "parse.c"
        break;
      case 231: /* foreach_clause ::= */
#line 1547 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_PARSER_GENERIC, "FOR EACH STATEMENT "
	       "triggers are not implemented, please supply FOR EACH ROW clause");
  pParse->is_aborted = true;
}
#line 3825 "parse.c"
        break;
      case 232: /* when_clause ::= */
#line 1556 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[1].minor.yy2 = 0; }
#line 3830 "parse.c"
        break;
      case 233: /* when_clause ::= WHEN expr */
#line 1557 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-1].minor.yy2 = yymsp[0].minor.yy150.pExpr; }
#line 3835 "parse.c"
        break;
      case 234: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1561 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  assert( yymsp[-2].minor.yy347!=0 );
  yymsp[-2].minor.yy347->pLast->pNext = yymsp[-1].minor.yy347;
  yymsp[-2].minor.yy347->pLast = yymsp[-1].minor.yy347;
}
#line 3844 "parse.c"
        break;
      case 235: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1566 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ 
  assert( yymsp[-1].minor.yy347!=0 );
  yymsp[-1].minor.yy347->pLast = yymsp[-1].minor.yy347;
}
#line 3852 "parse.c"
        break;
      case 236: /* trnm ::= nm DOT nm */
#line 1577 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;
  diag_set(ClientError, ER_SQL_PARSER_GENERIC, "qualified table names are not "\
           "allowed on INSERT, UPDATE, and DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3862 "parse.c"
        break;
      case 237: /* tridxby ::= INDEXED BY nm */
#line 1589 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX, "trigger body", "the INDEXED BY clause "\
           "is not allowed on UPDATE or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3871 "parse.c"
        break;
      case 238: /* tridxby ::= NOT INDEXED */
#line 1594 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX, "trigger body", "the NOT INDEXED "\
           "clause is not allowed on UPDATE or DELETE statements within "\
           "triggers");
  pParse->is_aborted = true;
}
#line 3881 "parse.c"
        break;
      case 239: /* trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt */
#line 1607 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
     yymsp[-6].minor.yy347 = sql_trigger_update_step(pParse->db, &yymsp[-4].minor.yy0, yymsp[-1].minor.yy402, yymsp[0].minor.yy2, yymsp[-5].minor.yy348);
     if (yymsp[-6].minor.yy347 == NULL) {
        pParse->is_aborted = true;
        return;
     }
   }
#line 3892 "parse.c"
        break;
      case 240: /* trigger_cmd ::= insert_cmd INTO trnm idlist_opt select */
#line 1616 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  /*yylhsminor.yy347-overwrites-yymsp[-4].minor.yy348. */
  yylhsminor.yy347 = sql_trigger_insert_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy272, yymsp[0].minor.yy43, yymsp[-4].minor.yy348);
  if (yylhsminor.yy347 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3904 "parse.c"
  yymsp[-4].minor.yy347 = yylhsminor.yy347;
        break;
      case 241: /* trigger_cmd ::= DELETE FROM trnm tridxby where_opt */
#line 1626 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy347 = sql_trigger_delete_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[0].minor.yy2);
  if (yymsp[-4].minor.yy347 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3916 "parse.c"
        break;
      case 242: /* trigger_cmd ::= select */
#line 1635 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  /* yylhsminor.yy347-overwrites-yymsp[0].minor.yy43. */
  yylhsminor.yy347 = sql_trigger_select_step(pParse->db, yymsp[0].minor.yy43);
  if (yylhsminor.yy347 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3928 "parse.c"
  yymsp[0].minor.yy347 = yylhsminor.yy347;
        break;
      case 243: /* expr ::= RAISE LP IGNORE RP */
#line 1645 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  spanSet(&yymsp[-3].minor.yy150,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-3].minor.yy150.pExpr = sqlPExpr(pParse, TK_RAISE, 0, 0);
  if( yymsp[-3].minor.yy150.pExpr ){
    yymsp[-3].minor.yy150.pExpr->on_conflict_action = ON_CONFLICT_ACTION_IGNORE;
  }
}
#line 3940 "parse.c"
        break;
      case 244: /* expr ::= RAISE LP raisetype COMMA STRING RP */
#line 1652 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy150,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-5].minor.yy150.pExpr = sql_expr_new_dequoted(pParse->db, TK_RAISE, &yymsp[-1].minor.yy0);
  if(yymsp[-5].minor.yy150.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy150.pExpr->on_conflict_action = (enum on_conflict_action) yymsp[-3].minor.yy348;
}
#line 3953 "parse.c"
        break;
      case 245: /* raisetype ::= ROLLBACK */
#line 1663 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = ON_CONFLICT_ACTION_ROLLBACK;}
#line 3958 "parse.c"
        break;
      case 246: /* raisetype ::= ABORT */
#line 1664 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = ON_CONFLICT_ACTION_ABORT;}
#line 3963 "parse.c"
        break;
      case 247: /* raisetype ::= FAIL */
#line 1665 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[0].minor.yy348 = ON_CONFLICT_ACTION_FAIL;}
#line 3968 "parse.c"
        break;
      case 248: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1669 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_trigger_def_init(&pParse->drop_trigger_def, yymsp[0].minor.yy3, &t, yymsp[-1].minor.yy348);
  pParse->initiateTTrans = true;
  sql_drop_trigger(pParse);
}
#line 3978 "parse.c"
        break;
      case 249: /* alter_table_start ::= ALTER TABLE fullname */
#line 1686 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-2].minor.yy120 = yymsp[0].minor.yy3; }
#line 3983 "parse.c"
        break;
      case 250: /* alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm */
#line 1689 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yylhsminor.yy426.table_name = yymsp[-3].minor.yy120;
  yylhsminor.yy426.name = yymsp[0].minor.yy0;
  pParse->initiateTTrans = true;
}
#line 3992 "parse.c"
  yymsp[-3].minor.yy426 = yylhsminor.yy426;
        break;
      case 251: /* cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 1696 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, yymsp[-11].minor.yy426.table_name, &yymsp[-11].minor.yy426.name, yymsp[-7].minor.yy402, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy402,
                     yymsp[-2].minor.yy348, yymsp[-1].minor.yy348, yymsp[0].minor.yy348);
  sql_create_foreign_key(pParse);
}
#line 4002 "parse.c"
        break;
      case 252: /* cmd ::= alter_add_constraint CHECK LP expr RP */
#line 1702 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
    create_ck_def_init(&pParse->create_ck_def, yymsp[-4].minor.yy426.table_name, &yymsp[-4].minor.yy426.name, &yymsp[-1].minor.yy150);
    sql_create_check_contraint(pParse);
}
#line 4010 "parse.c"
        break;
      case 253: /* cmd ::= alter_add_constraint unique_spec LP sortlist RP */
#line 1707 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, yymsp[-4].minor.yy426.table_name, &yymsp[-4].minor.yy426.name, yymsp[-1].minor.yy402, yymsp[-3].minor.yy348,
                        SORT_ORDER_ASC, false);
  sql_create_index(pParse);
}
#line 4019 "parse.c"
        break;
      case 254: /* unique_spec ::= UNIQUE */
#line 1714 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy348 = SQL_INDEX_TYPE_CONSTRAINT_UNIQUE; }
#line 4024 "parse.c"
        break;
      case 255: /* unique_spec ::= PRIMARY KEY */
#line 1715 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-1].minor.yy348 = SQL_INDEX_TYPE_CONSTRAINT_PK; }
#line 4029 "parse.c"
        break;
      case 256: /* cmd ::= alter_table_start RENAME TO nm */
#line 1717 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
    rename_entity_def_init(&pParse->rename_entity_def, yymsp[-3].minor.yy120, &yymsp[0].minor.yy0);
    pParse->initiateTTrans = true;
    sql_alter_table_rename(pParse);
}
#line 4038 "parse.c"
        break;
      case 257: /* cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm */
#line 1723 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  drop_fk_def_init(&pParse->drop_fk_def, yymsp[-3].minor.yy3, &yymsp[0].minor.yy0, false);
  pParse->initiateTTrans = true;
  sql_drop_foreign_key(pParse);
}
#line 4047 "parse.c"
        break;
      case 258: /* with ::= */
#line 1735 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{yymsp[1].minor.yy4 = 0;}
#line 4052 "parse.c"
        break;
      case 259: /* with ::= WITH wqlist */
#line 1736 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-1].minor.yy4 = yymsp[0].minor.yy4; }
#line 4057 "parse.c"
        break;
      case 260: /* with ::= WITH RECURSIVE wqlist */
#line 1737 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[-2].minor.yy4 = yymsp[0].minor.yy4; }
#line 4062 "parse.c"
        break;
      case 261: /* wqlist ::= nm eidlist_opt AS LP select RP */
#line 1739 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy4 = sqlWithAdd(pParse, 0, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy402, yymsp[-1].minor.yy43); /*A-overwrites-X*/
}
#line 4069 "parse.c"
        break;
      case 262: /* wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP */
#line 1742 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy4 = sqlWithAdd(pParse, yymsp[-7].minor.yy4, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy402, yymsp[-1].minor.yy43);
}
#line 4076 "parse.c"
        break;
      case 263: /* typedef ::= TEXT */
      case 264: /* typedef ::= STRING_KW */ yytestcase(yyruleno==264);
#line 1748 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy434.type = FIELD_TYPE_STRING; }
#line 4082 "parse.c"
        break;
      case 265: /* typedef ::= SCALAR */
#line 1750 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy434.type = FIELD_TYPE_SCALAR; }
#line 4087 "parse.c"
        break;
      case 266: /* typedef ::= BOOL */
      case 267: /* typedef ::= BOOLEAN */ yytestcase(yyruleno==267);
#line 1752 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy434.type = FIELD_TYPE_BOOLEAN; }
#line 4093 "parse.c"
        break;
      case 268: /* typedef ::= VARBINARY */
#line 1754 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy434.type = FIELD_TYPE_VARBINARY; }
#line 4098 "parse.c"
        break;
      case 269: /* char_len ::= LP INTEGER RP */
#line 1766 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  (void) yymsp[-2].minor.yy348;
  (void) yymsp[-1].minor.yy0;
}
#line 4106 "parse.c"
        break;
      case 270: /* typedef ::= VARCHAR char_len */
#line 1772 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy434.type = FIELD_TYPE_STRING;
  (void) yymsp[0].minor.yy348;
}
#line 4114 "parse.c"
        break;
      case 271: /* number_typedef ::= NUMBER */
#line 1779 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy434.type = FIELD_TYPE_NUMBER; }
#line 4119 "parse.c"
        break;
      case 272: /* number_typedef ::= INT|INTEGER_KW */
#line 1780 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy434.type = FIELD_TYPE_INTEGER; }
#line 4124 "parse.c"
        break;
      case 273: /* number_typedef ::= UNSIGNED */
#line 1781 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"
{ yymsp[0].minor.yy434.type = FIELD_TYPE_UNSIGNED; }
#line 4129 "parse.c"
        break;
      default:
      /* (274) input ::= ecmd */ yytestcase(yyruleno==274);
      /* (275) explain ::= */ yytestcase(yyruleno==275);
      /* (276) cmdx ::= cmd (OPTIMIZED OUT) */ assert(yyruleno!=276);
      /* (277) savepoint_opt ::= SAVEPOINT */ yytestcase(yyruleno==277);
      /* (278) savepoint_opt ::= */ yytestcase(yyruleno==278);
      /* (279) cmd ::= create_table create_table_args */ yytestcase(yyruleno==279);
      /* (280) columnlist ::= columnlist COMMA tcons */ yytestcase(yyruleno==280);
      /* (281) columnlist ::= columnlist COMMA columnname carglist */ yytestcase(yyruleno==281);
      /* (282) columnlist ::= columnname carglist */ yytestcase(yyruleno==282);
      /* (283) columnlist ::= tcons (OPTIMIZED OUT) */ assert(yyruleno!=283);
      /* (284) carglist ::= carglist ccons */ yytestcase(yyruleno==284);
      /* (285) carglist ::= */ yytestcase(yyruleno==285);
      /* (286) ccons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=286);
      /* (287) tcons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=287);
      /* (288) defer_subclause_opt ::= defer_subclause (OPTIMIZED OUT) */ assert(yyruleno!=288);
      /* (289) resolvetype ::= raisetype (OPTIMIZED OUT) */ assert(yyruleno!=289);
      /* (290) selectnowith ::= oneselect (OPTIMIZED OUT) */ assert(yyruleno!=290);
      /* (291) oneselect ::= values */ yytestcase(yyruleno==291);
      /* (292) sclp ::= selcollist COMMA */ yytestcase(yyruleno==292);
      /* (293) as ::= ID|STRING */ yytestcase(yyruleno==293);
      /* (294) join_nm ::= ID|INDEXED */ yytestcase(yyruleno==294);
      /* (295) join_nm ::= JOIN_KW */ yytestcase(yyruleno==295);
      /* (296) expr ::= term (OPTIMIZED OUT) */ assert(yyruleno!=296);
      /* (297) type_func ::= CHAR */ yytestcase(yyruleno==297);
      /* (298) exprlist ::= nexprlist */ yytestcase(yyruleno==298);
      /* (299) nmnum ::= plus_num (OPTIMIZED OUT) */ assert(yyruleno!=299);
      /* (300) nmnum ::= STRING */ yytestcase(yyruleno==300);
      /* (301) nmnum ::= TRUE */ yytestcase(yyruleno==301);
      /* (302) nmnum ::= FALSE */ yytestcase(yyruleno==302);
      /* (303) nmnum ::= nm */ yytestcase(yyruleno==303);
      /* (304) nmnum ::= ON */ yytestcase(yyruleno==304);
      /* (305) nmnum ::= DELETE */ yytestcase(yyruleno==305);
      /* (306) nmnum ::= DEFAULT */ yytestcase(yyruleno==306);
      /* (307) plus_num ::= INTEGER|FLOAT */ yytestcase(yyruleno==307);
      /* (308) foreach_clause ::= FOR EACH ROW */ yytestcase(yyruleno==308);
      /* (309) trnm ::= nm */ yytestcase(yyruleno==309);
      /* (310) tridxby ::= */ yytestcase(yyruleno==310);
      /* (311) typedef ::= number_typedef (OPTIMIZED OUT) */ assert(yyruleno!=311);
        break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
/************ End %parse_failure code *****************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  sqlParserTOKENTYPE yyminor         /* The minor type of the error token */
){
  sqlParserARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 32 "/build/usr/src/debug/tarantool-2.2.2.71/src/box/sql/parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  if (yypParser->is_fallback_failed && TOKEN.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, TOKEN.n, TOKEN.z,
             TOKEN.n, TOKEN.z);
  } else {
    diag_set(ClientError, ER_SQL_UNRECOGNIZED_SYNTAX, TOKEN.n, TOKEN.z);
  }
  pParse->is_aborted = true;
#line 4237 "parse.c"
/************ End %syntax_error code ******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
  assert( yypParser->yytos==yypParser->yystack );
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
/*********** End %parse_accept code *******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlParser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlParserTOKENTYPE yyminor       /* The value for the token */
  sqlParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  sqlParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack
         PARSER_ERROR_CHECK);
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
  }
#endif
  return;
}
